@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: login.php,v 1.45 2004/03/06 16:53:35 toddy Exp $
+# $Id: login.php,v 1.46 2004/03/28 18:11:57 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -88,12 +88,13 @@ if ($login)
     }
 }
 
-if ($session_hash)
-{
-  #nuke their old session
-  session_cookie('session_hash','');
-  db_query("DELETE FROM session WHERE session_hash='$session_hash'");
-}
+## UNSECURE
+##if ($session_hash)
+##{
+##  #nuke their old session
+##  session_cookie('session_hash','');
+## db_query("DELETE FROM session WHERE session_hash='$session_hash'");
+##}
 
 site_header(array('title'=>_("Login")));
 
