@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: account.php,v 1.17 2004/02/15 12:40:38 yeupou Exp $
+# $Id: account.php,v 1.18 2004/03/26 17:17:59 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -38,9 +38,22 @@ function account_pwvalid ($pw)
   return 1;
 }
 
-function account_namevalid ($name)
+function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_namevalid ($name)';
+  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_namevalid ($name)';
+  # By default, underscore are allowed, creating no specific issue for an
+  # account name. It may creates trouble if the account is use to handle DNS...
+  if ($allow_underscores) {
+    $underscore = "_";
+  }
+
+  # By default, dashes are not allowed, creating issue with mailing list name
+  # and many other potential conflicts. However, it is usually convenient for
+  # groups name.
+  if ($allow_dashes) {
+    $dashes = "-";
+  }
+  
   # no spaces
   if (strrpos($name,' ') > 0)
     {
@@ -49,35 +62,39 @@ function account_namevalid ($name)
     }
 
   # min and max length
-  $MIN_ACCNAME_LENGTH= 2;
-  $MAX_ACCNAME_LENGTH= 15;
+  $MIN_ACCNAME_LENGTH= 3;
+  $MAX_ACCNAME_LENGTH= 19;
 
   if (strlen($name) < $MIN_ACCNAME_LENGTH)
     {
-      $GLOBALS['register_error'] = sprintf(_("Login name is too short. It must be at least %i characters."),$MIN_ACCNAME_LENGTH);
+      $GLOBALS['register_error'] = sprintf(_("Account name is too short. It must be at least %i characters."), $MIN_ACCNAME_LENGTH);
       return 0;
     }
 
   if (strlen($name) > $MAX_ACCNAME_LENGTH)
     {
-      $GLOBALS['register_error'] = sprintf(_("Login name is too long. It must be at most %i characters."),$MAX_ACCNAME_LENGTH);
+      $GLOBALS['register_error'] = sprintf(_("Account name is too long. It must be at most %i characters."), $MAX_ACCNAME_LENGTH);
       return 0;
     }
 
-  # must start with an alphanumeric non numerical
+  # must start with an alphanumeric non numeric
   if (strspn($name,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ") == 0)
     {
-      $GLOBALS['register_error'] = _("Login name must begin with an alphanumeric character.");
+      $GLOBALS['register_error'] = _("Account name must begin with an alphabetical character.");
       return 0;
     }
 
-  # must contain all legal characters, no dashes to reserved dashed name to
-  # mailing-list.
-
-  if (strspn($name,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_")
+  # must contain only legal characters and underscores, and maybe dashes and 
+  # underscore, depending on the arguments
+  if (strspn($name,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789$underscore$dashes")
       != strlen($name))
     {
-      $GLOBALS['register_error'] = _("Login name must only contain alphanumerics and underscores.");
+      if ($allow_underscore) 
+	{ $GLOBALS['register_error'] = _("Account name must only contain alphanumerics and underscores."); }
+      elseif ($allow_dashes) 
+	{ $GLOBALS['register_error'] = _("Account name must only contain alphanumerics and dashes."); }
+      else { $GLOBALS['register_error'] = _("Account name must only contain alphanumerics."); }
+
       return 0;
     }
     
@@ -86,7 +103,7 @@ function account_namevalid ($name)
 	    . "|(uucp)|(operator)|(invalid)|(games)|(mysql)|(httpd)|(nobody)|(dummy)|(opensource)"
 	    . "|(web)|(www)|(cvs)|(anoncvs)|(anonymous)|(shell)|(ftp)|(irc)|(debian)|(ns)|(download))$",$name))
     {
-      $GLOBALS['register_error'] = _("That login name is reserved.");
+      $GLOBALS['register_error'] = _("That account name is reserved.");
       return 0;
     }
 		
@@ -97,7 +114,8 @@ function account_groupnamevalid ($name)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_groupnamevalid ';
   
-  if (!account_namevalid($name)) 
+  # Test with the usual namevalid function, allowing dashes
+  if (!account_namevalid($name, 1, 0)) 
     { return 0; }
   
   utils_get_content("forbidden_group_names");
