@@ -1,32 +1,29 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: html.php,v 1.45 2004/02/29 18:37:42 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright (C) 2000-2003 Free Software Foundation
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: html.php,v 1.48 2004/03/30 07:20:01 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#                          Mathieu Roy <yeupou--at--gnu.org>
+#
+#  Copyright 2004      (c) ...
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 function html_nextprev ($search_url, $rows, $rows_returned)
 {
@@ -68,29 +65,30 @@ function html_feedback_top()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_top() ';
   if ($GLOBALS[feedback])
-    {  print '<h3 class="feedback">'.$GLOBALS[feedback].'</h3>'; }
+    {  print '<h3 class="feedback">'.htmlentities($GLOBALS[feedback]).'</h3>'; }
   if ($GLOBALS[ffeedback])
-    {  print '<h3 class="feedbackerror">'.$GLOBALS[ffeedback].'</h3>'; }
+    {  print '<h3 class="feedbackerror">'.htmlentities($GLOBALS[ffeedback]).'</h3>'; }
   if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
-    {  print '<h3 class="feedbackerror">DEBUG information: '.$GLOBALS[debug].'</h3>'; }
-  // yeupou@gnu.org 2003-11-03:
-  // We unset feedback so there will be a bottom feedback only if something
-  // changed. It may confuse users, however I would find more confusing to
-  // have to lookalike feedback information providing most of the time the
-  // same information AND (that's the problem) sometimes more information
-  // in the second one.
+    {  print '<h3 class="feedbackerror">DEBUG information: '.htmlentities($GLOBALS[debug]).'</h3>'; }
+  # yeupou@gnu.org 2003-11-03:
+  # We unset feedback so there will be a bottom feedback only if something
+  # changed. It may confuse users, however I would find more confusing to
+  # have to lookalike feedback information providing most of the time the
+  # same information AND (that's the problem) sometimes more information
+  # in the second one.
   unset($GLOBALS[feedback],$GLOBALS[ffeedback],$GLOBALS[debug]);
 }
 
 function html_feedback_bottom()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_bottom() ';
-  if ($GLOBALS[feedback])
-    {  print '<h3 class="feedback">'.$GLOBALS[feedback].'</h3>'; }
+ 
+ if ($GLOBALS[feedback])
+    {  print '<h3 class="feedback">'.htmlentities($GLOBALS[feedback]).'</h3>'; }
   if ($GLOBALS[ffeedback])
-    {  print '<h3 class="feedbackerror">'.$GLOBALS[ffeedback].'</h3>'; }
+    {  print '<h3 class="feedbackerror">'.htmlentities($GLOBALS[ffeedback]).'</h3>'; }
   if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
-    {  print '<h3 class="feedbackerror">DEBUG information: '.$GLOBALS[debug].'</h3>'; }
+    {  print '<h3 class="feedbackerror">DEBUG information: '.htmlentities($GLOBALS[debug]).'</h3>'; }
 }
 
 function html_a_group($grp)
@@ -116,10 +114,10 @@ function html_image($src,$args,$display=1)
       $return .= ' '.$k.'="'.$v.'"';
     }
 
-  // ## insert a border tag if there isn't one
+  # ## insert a border tag if there isn't one
   if (!$args['border']) $return .= (' border="0"');
 
-  // ## if no height AND no width tag, insert em both
+  # ## if no height AND no width tag, insert em both
   if (!$args['height'] && !$args['width'])
     {
       /* Check to see if we've already fetched the image data */
@@ -137,7 +135,7 @@ function html_image($src,$args,$display=1)
       $return .= ' ' . $img_size[$src];
     }
 
-  // ## insert alt tag if there isn't one
+  # ## insert alt tag if there isn't one
   if (!$args['alt']) $return .= " alt=\"$src\"";
 
   $return .= ('>');
@@ -207,7 +205,7 @@ function html_get_alt_row_color ($i)
     }
 }
 
-//deprecated
+#deprecated
 function utils_get_alt_row_color ($i)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':utils_get_alt_row_color ($i) ';
@@ -295,14 +293,14 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
 		<SELECT NAME="'.$select_name.'">';
 
 
-  //we don't always want the default any  row shown
+  #we don't always want the default any  row shown
   if ($show_any)
     {
       $selected = ( $checked_val == 0 ? 'SELECTED':'');
       $return .= "\n<OPTION VALUE=\"0\" $selected>$text_any </OPTION>";
     }
 
-  //we don't always want the default 100 row shown
+  #we don't always want the default 100 row shown
   if ($show_100)
     {
       $selected = ( $checked_val == 100 ? 'SELECTED':'');
@@ -317,8 +315,8 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
 
   for ($i=0; $i<$rows; $i++)
     {
-      //  uggh - sorry - don't show the 100 row and Any row
-      //  if it was shown above, otherwise do show it
+      #  uggh - sorry - don't show the 100 row and Any row
+      #  if it was shown above, otherwise do show it
       if ( (($vals[$i] != '100') && ($vals[$i] != '0')) ||
 	   ($vals[$i] == '100' && !$show_100) ||
 	   ($vals[$i] == '0' && !$show_any) )
@@ -377,7 +375,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
   */
 
   $checked_count=count($checked_array);
-  //      print '-- '.$checked_count.' --';
+  #      print '-- '.$checked_count.' --';
   $return .= '
 		<SELECT NAME="'.$name.'" MULTIPLE SIZE="'.$size.'">';
   /*
@@ -445,8 +443,8 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 function html_select_permission_box ($artifact, $row, $level="member")
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_permission_box ($artifact, $row, $level="member")';
-  // If $row['user_id'] does not exists, we havent got a row but simple value
-  // and it means that we are about to modify per group default
+  # If $row['user_id'] does not exists, we havent got a row but simple value
+  # and it means that we are about to modify per group default
   if ($level == "type")
     {
       $value = $row;
@@ -507,10 +505,10 @@ function html_select_permission_box ($artifact, $row, $level="member")
     </td>';
 }
 
-// This function must now every type of directory that can be built by the
-// backend.
-// FIXME: in a future, we may create a table of method associating
-// method -> perl module -> sub name
+# This function must now every type of directory that can be built by the
+# backend.
+# FIXME: in a future, we may create a table of method associating
+# method -> perl module -> sub name
 function html_select_typedir_box ($input_name, $current_value)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_typedir_box ';
@@ -522,26 +520,26 @@ function html_select_typedir_box ($input_name, $current_value)
       </select> [BACKEND SPECIFIC]
 ';
 
-  // put some information
+  # put some information
   print '<br><font class="italic">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br>
 (If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savannah-dev@gnu.org to get information about that)</font><br>';
 
 }
 
-// Print an theme select box. This function will add the special rotate
-// and random meta-themes. This function will hide disallowed theme.
-// That is said that theme are not strictly forbidden, someone can
-// forge a form and choose a forbidden theme.
-// But it is really not a big deal and it is better to have making to
-// many checks in theme_list(), which is frequently ran, unlike this
-// one.
+# Print an theme select box. This function will add the special rotate
+# and random meta-themes. This function will hide disallowed theme.
+# That is said that theme are not strictly forbidden, someone can
+# forge a form and choose a forbidden theme.
+# But it is really not a big deal and it is better to have making to
+# many checks in theme_list(), which is frequently ran, unlike this
+# one.
 function html_select_theme_box ($input_name="user_theme", $current=0)
 {
 
   print  '
 		<select name="'.$input_name.'">';
 
-  // usual themes
+  # usual themes
   $data = theme_list(1);
   while (list(,$theme) = each($data))
     {
@@ -554,13 +552,13 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
       print '</option>'."\n";
     }
 
-  // special rotate case
+  # special rotate case
   $theme = "rotate";
   print "\n\t\t".'<option value="'.$theme.'"';
   if ($theme == $current)
     { print ' selected'; }
   print '>'.$theme.' ('.("a different theme alphabetically picked everyday").')</option>';
-  // special random case
+  # special random case
   $theme = "random";
   print "\n\t\t".'<option value="'.$theme.'"';
   if ($theme == $current)
@@ -632,7 +630,7 @@ function html_build_checkboxarray($options,$name,$checked_array)
 function html_buildcheckboxarray($options,$name,$checked_array)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_buildcheckboxarray ';
-  //deprecated
+  #deprecated
   return html_build_checkboxarray($options,$name,$checked_array);
 }
 
@@ -692,26 +690,26 @@ function site_project_header($params)
 
   $group_id=$params['group'];
 
-  //get the project object
+  #get the project object
   $project=project_get_object($group_id);
 
-  //group doesn't exist
+  #group doesn't exist
   if ($project->isError())
     {
       exit_error("Invalid Group $group_id","That group does not exist.");
     }
 
-  //group is private
+  #group is private
   if (!$project->isPublic())
     {
-      //if its a private group, you must be a member of that group
+      #if its a private group, you must be a member of that group
       session_require(array('group'=>$group_id));
     }
 
-  //for dead projects must be member of admin project
+  #for dead projects must be member of admin project
   if (!$project->isActive())
     {
-      // only sys_group people can view non-active, non-holding groups
+      # only sys_group people can view non-active, non-holding groups
       session_require(array('group'=>$GLOBALS['sys_group_id']));
     }
 
