@@ -1,33 +1,27 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: general.php,v 1.4 2004/03/04 21:33:14 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
-
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: general.php,v 1.11 2004/03/20 14:50:58 toddy Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#
+#  Copyright 2004      (c) ...
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_from="no")
 {
@@ -41,10 +35,10 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
       $group_id = $GLOBALS['sys_group_id'];
     }
 
-  // We want the total number of news
+  # We want the total number of news
   $news_total=news_total_number($group_id);
 
-  // We fetch news item for that group
+  # We fetch news item for that group
   if ($group_id != $GLOBALS['sys_group_id'])
     {
       $wclause="news_bytes.group_id='$group_id' AND news_bytes.is_approved <> 4 AND news_bytes.is_approved <> 5";
@@ -83,26 +77,28 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
     {
       for ($i=0; $i<$rows; $i++)
 	{
-	  // We want the number of message in this forum
+	  # We want the number of message in this forum
 	  $tres_count = db_query("SELECT group_forum_id FROM forum WHERE group_forum_id='". db_result($result,$i,'forum_id') ."'");
 	  $trow_count = db_numrows($tres_count);
 	  if ($show_summaries != "false")
 	    {
-	      // Get the first paragraph of the story
-	      $arr=explode("\n",db_result($result,$i,'details'));
-
-	      // If the first paragraph is short, and so
-	      // are following paragraphs, add the next paragraph on
-	      if ((strlen($arr[0]) < 200) && (strlen($arr[1].$arr[2]) < 300) && (strlen($arr[2]) > 5))
-		{
-		  $summ_txt='<br>'. utils_make_links( $arr[0].'<br>'.$arr[1].'<br>'.$arr[2], $group_id ).'<br><br>';
+	      # Get the story
+	      $story = rtrim(db_result($result,$i,'details'));
+	      if (strlen($story) > 250)
+	        {
+	          # create an abstract with a [read more] link
+		  $summ_txt = substr($story, 0, 250);
+		  $summ_txt = substr($summ_txt, 0, strrpos($summ_txt, ' '));
+		  $summ_txt .= "...";
+		  $summ_txt = '<br /><br />'.utils_make_links(nl2br($summ_txt), $group_id);
+	          $summ_txt .= sprintf(_("%s[Read more]%s"), '<br /><a href="'.$GLOBALS['sys_home'].'forum/forum.php?forum_id='.db_result($result,$i,'forum_id').'">', '</a>');
 		}
 	      else
-		{
-		  $summ_txt='<br>'. utils_make_links( $arr[0], $group_id ).'<br><br>';
+	        {
+		  # this is a short news item. just display it.
+		  $summ_txt = '<br /><br />'.utils_make_links(nl2br($story), $group_id);
 		}
 	      $proj_name = db_result($result,$i,'group_name');
-	      $summ_txt .= sprintf(_("%s[Read more...]%s"), '<a href="'.$GLOBALS['sys_home'].'forum/forum.php?forum_id='.db_result($result,$i,'forum_id').'">', '</a>');
 	    }
 	  else
 	    {
@@ -134,12 +130,12 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
   if ($start_from != "nolinks")
     {
 
-      // No link is a trick to skip archives + submit news links
+      # No link is a trick to skip archives + submit news links
 
       if ($group_id != $GLOBALS['sys_group_id'])
 	{
-	  // You can only submit news from a project now.
-	  // You used to be able to submit general news.
+	  # You can only submit news from a project now.
+	  # You used to be able to submit general news.
 	  $return .= '<tr><td class="'.utils_get_alt_row_color($i).'">'
 	     .'<a href="'.$GLOBALS['sys_home'].'news/submit.php?group_id='
 	     .$group_id.'"><font size="-1">['._("Submit News").']</font></a>'
@@ -159,7 +155,7 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 function news_total_number($group_id)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':news_total_number($group_id) ';
-  // We want the total number of news for a group
+  # We want the total number of news for a group
   if ($group_id != $GLOBALS['sys_group_id'])
     {
       $wclause="news_bytes.group_id='$group_id' AND news_bytes.is_approved <> 4 AND news_bytes.is_approved <> 5";
