@@ -1,32 +1,27 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: job.php,v 1.4 2004/03/03 19:11:35 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: job.php,v 1.5 2004/03/13 18:22:06 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#
+#  Copyright 2004      (c) ...
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
 function people_job_status_box($name='status_id',$checked='xyxy')
@@ -51,12 +46,12 @@ function people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_ye
   global $feedback;
   if (user_isloggedin())
     {
-      //check if they've already added this skill
+      #check if they've already added this skill
       $sql="SELECT * FROM people_job_inventory WHERE job_id='$job_id' AND skill_id='$skill_id'";
       $result=db_query($sql);
       if (!$result || db_numrows($result) < 1)
 	{
-	  //skill isn't already in this inventory
+	  #skill isn't already in this inventory
 	  $sql="INSERT INTO people_job_inventory (job_id,skill_id,skill_level_id,skill_year_id) ".
 	     "VALUES ('$job_id','$skill_id','$skill_level_id','$skill_year_id')";
 	  $result=db_query($sql);
@@ -186,8 +181,8 @@ function people_edit_job_inventory($job_id,$group_id)
 	}
 
     }
-  //add a new skill
-  $i++; //for row coloring
+  #add a new skill
+  $i++; #for row coloring
 
   echo '
 	<tr><td colspan="4"><h3>'._("Add A New Skill").'</h3></td></tr>
@@ -210,9 +205,9 @@ function people_show_job_list($result, $edit=0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_job_list($result, $edit=0) ';
   global $sys_datefmt;
-  //takes a result set from a query and shows the jobs
+  #takes a result set from a query and shows the jobs
 
-  //query must contain 'group_id', 'job_id', 'title', 'category_name', 'status_name' and 'type'
+  #query must contain 'group_id', 'job_id', 'title', 'category_name', 'status_name' and 'type'
 
   $title_arr=array();
   $title_arr[]=_("Title");
@@ -232,7 +227,7 @@ function people_show_job_list($result, $edit=0)
     {
       for ($i=0; $i < $rows; $i++)
 	{
-	  // get type infos
+	  # get type infos
 	  $res_type = db_query("SELECT name FROM group_type WHERE type_id=".db_result($result, $i, 'type'));
 
 	  if ($edit)
@@ -265,7 +260,7 @@ function people_show_job_list($result, $edit=0)
 function people_show_project_jobs($group_id,$edit=0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_project_jobs($group_id,$edit=0) ';
-  //show open jobs for this project
+  #show open jobs for this project
   $sql="SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,groups.type,people_job.title,people_job.date,people_job_category.name AS category_name ".
      "FROM people_job,people_job_category,groups ".
      "WHERE people_job.group_id='$group_id' ".
@@ -280,7 +275,7 @@ function people_show_project_jobs($group_id,$edit=0)
 function people_project_jobs_rows($group_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_project_jobs_rows($group_id) ';
-  //show open jobs for this project
+  #show open jobs for this project
   $sql="SELECT people_job.group_id,people_job.job_id,groups.group_name,people_job.title,people_job.date,people_job_category.name AS category_name ".
      "FROM people_job,people_job_category,groups ".
      "WHERE people_job.group_id='$group_id' ".
