@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pre.php,v 1.71 2004/02/15 12:40:38 yeupou Exp $
+# $Id: pre.php,v 1.74 2004/03/27 11:18:11 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -137,7 +137,10 @@ require $GLOBALS['sys_urlroot'].'/include/utils.php';
 require $GLOBALS['sys_urlroot'].'/include/session.php';
 
 # theme - color scheme informations
-require $GLOBALS['sys_urlroot'].'/include/theme2.php';
+require $GLOBALS['sys_urlroot'].'/include/theme.php';
+
+# title, helper to find out appropriate page title
+require $GLOBALS['sys_urlroot'].'/include/title.php';
 
 # HTML layout class, may be overriden by the Theme class
 require $GLOBALS['sys_urlroot'].'/include/Layout.class';
