@@ -1,36 +1,36 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: project_home.php,v 1.104 2004/02/29 18:37:42 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-// Copyright 2000-2003 (c) Free Software Foundation
-// Copyright 2004      (c) Mathieu Roy <yeupou@gnu.org>
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: project_home.php,v 1.106 2004/03/14 19:38:59 yeupou Exp $
+#
+# Copyright 1999-2000 (c) The SourceForge Crew
+# Copyright 2000-2003 (c) Free Software Foundation
+#
+# Copyright 2002-2004 (c) Mathieu Roy <yeupou@gnu.org>
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 require_directory("people");
 require_directory("news");
 require $GLOBALS['sys_urlroot']."/include/vars.php";
 
-// if we are at wrong url, redirect
+# if we are at wrong url, redirect
 if ($HTTP_HOST != $project->getTypeBaseHost() && $project->getTypeBaseHost())
 {
-  header ("Location: http".(session_issecure()?'s':'')."://".$project->getTypeBaseHost().$PHP_SELF);
+  header ("Location: http".(session_issecure()?'s':'').":#".$project->getTypeBaseHost().$PHP_SELF);
   exit;
 }
 
@@ -39,22 +39,22 @@ site_project_header(array('group'=>$group_id,
 			  'toptab'=>'home'));
 
 
-// ########################################### end top area
+# ########################################### end top area
 
-// two column deal
+# two column deal
 
 print '<table width="100%" border="0">
 <tr><td class="indexcenter">';
 
 
-// ########################################## top area, not in box
+# ########################################## top area, not in box
 
 $res_admin = db_query("SELECT user.user_id AS user_id,user.user_name AS user_name, user.realname AS realname "
 		      . "FROM user,user_group "
 		      . "WHERE user_group.user_id=user.user_id AND user_group.group_id=$group_id AND "
 		      . "user_group.admin_flags = 'A'");
 
-// ########################### General Informations
+# ########################### General Informations
 
 print '<p>'.$project->getTypeDescription()."</p>\n";
 
@@ -96,8 +96,8 @@ if ($project->CanUse("devel_status"))
 }
 print '</p></td><td nowrap class="indexright">';
 
-// ########################### Members of this project
-// (little box on the right)
+# ########################### Members of this project
+# (little box on the right)
 
 print $HTML->box1_top(_("Membership Info"));
 $adminsnum = db_numrows($res_admin);
@@ -111,14 +111,14 @@ if ($adminsnum > 0)
   }
 }
 
-//count of developers on this project
+#count of developers on this project
 $membersnum = db_fetch_array(db_query("SELECT COUNT(*) AS count FROM user_group WHERE group_id=$group_id AND admin_flags<>'P'"));
 print '<br><br>'._("Members").': <font class="bold">'.$membersnum[count].'</font>';
 
-// if member = 1, it's obviously (or it should be) the project admin
-// if there's no admin, we need to get access to the list
-// But we show it anyway: this page can be used for request for membership,
-// provide more info that the little infobox.
+# if member = 1, it's obviously (or it should be) the project admin
+# if there's no admin, we need to get access to the list
+# But we show it anyway: this page can be used for request for membership,
+# provide more info that the little infobox.
 print '<br>&nbsp; <a href="'.$GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name.'">[View&nbsp;&nbsp;Members]</a>';
 
 
@@ -135,8 +135,8 @@ print '<table width="100%">';
 print '<tr><td valign="top" width="50%">'."\n\n";
 
 
-// ############################## ADMIN AREA ###########################
-// #######################################################################
+# ############################## ADMIN AREA ###########################
+# #######################################################################
 
 if ($GLOBALS[sys_group_id] == $group_id)
 {
@@ -177,14 +177,14 @@ if (member_check(0, $group_id, 'A'))
 }
 
 
-// ############################## PUBLIC AREAS ###########################
-// #######################################################################
+# ############################## PUBLIC AREAS ###########################
+# #######################################################################
 
-// ################################## QUICK OVERVIEW
+# ################################## QUICK OVERVIEW
 
 function specific_makesep ()
 {
-  // too specific to be general function
+  # too specific to be general function
   global $i, $j;
   if ($i != $j)
     {
@@ -196,7 +196,7 @@ function specific_makesep ()
 print $HTML->box1_top(_("Public Areas: Quick Overview"));
 $i = 1;
 $j = $i;
-// Homepage Link
+# Homepage Link
 
 if ($project->Uses("homepage"))
 {
@@ -206,7 +206,7 @@ if ($project->Uses("homepage"))
   $i++;
 }
 
-// Documentation (extra link)
+# Documentation (extra link)
 if ($project->Uses("extralink_documentation"))
 {
   specific_makesep();
@@ -217,19 +217,19 @@ if ($project->Uses("extralink_documentation"))
   $i++;
 }
 
-// Download area
+# Download area
 if($project->Uses("download")) {
   specific_makesep();
 
-  // the pointer is always the filelist, this page will handle redirect
-  // appropriately in case that no download area is here
+  # the pointer is always the filelist, this page will handle redirect
+  # appropriately in case that no download area is here
   print '<a href="'.$project->getArtifactUrl("files").'">';
   print html_image("download.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Filelist'));
   print '&nbsp;'._("Filelist").' ('._("Download area").')</a>';
   $i++;
 }
 
-// Memberlist
+# Memberlist
 specific_makesep();
 print '<a href="'.$GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name.'">';
 print html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Memberlist'));
@@ -240,7 +240,7 @@ $HTML->box1_bottom();
 print '<br>';
 
 
-// ################################## COMMUNICATION
+# ################################## COMMUNICATION
 
 if ($GLOBALS[sys_unix_group_name] == $group_name ||
     $project->Uses("support") ||
@@ -261,7 +261,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
   }
 
 
-  // Support Manager
+  # Support Manager
 
   if ($project->Uses("support")) {
     specific_makesep();
@@ -288,8 +288,8 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
   }
 
 
-  // Fora
-  // It must be reactivated on Savannah.
+  # Fora
+  # It must be reactivated on Savannah.
 
   if ($project->Uses("forum")) {
     specific_makesep();
@@ -319,7 +319,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 
   }
 
-  // Mailing lists
+  # Mailing lists
 
   if ($project->usesMail())
     {
@@ -335,7 +335,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
       $i++;
     }
 
-  // Looking for people
+  # Looking for people
 
   if (people_project_jobs_rows($group_id) != 0) {
     specific_makesep();
@@ -350,7 +350,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
   print '<br>';
 }
 
-// ################################## DEVELOPMENT
+# ################################## DEVELOPMENT
 
 if ($project->Uses("patch") ||
     $project->Uses("cvs") ||
@@ -363,34 +363,33 @@ if ($project->Uses("patch") ||
   $i = 1;
   $j = $i;
 
-  // CVS
+  # CVS
 
-  if ($project->Uses("cvs") || $project->Uses("homepage"))
+  if (($project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '') || ($project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '' && $project->Uses("homepage")))
     {
-      // FIXME is_type_homepage_on_cvs no longer exists. The test should be
-      // made upon the kind of directory is supposed to be, not CanUse("homepage").
+      
       $url = $project->getArtifactUrl("cvs");
-
+      
       html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'CVS'));
       print '&nbsp;<a href="'.$url.'">'._("CVS Repository").'</a>';
 
       if ($project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '')
 	{
-	  print '<br> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs").'">Browse Sources Repository</A>';
+	  print '<br> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs").'">'._("Browse Sources Repository").'</a>';
 	}
       if ($project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '' && $project->Uses("homepage"))
 	{
-	  // Consider that this link is valid if not empty or not 'http://'
-	  // (default).
-	  // Only the backend should make use of the is_homepage_on_cvs value,
-	  // because and homepage can be on CVS with this flag off: this flag
-	  // is used to determine whether a CVSROOT must be created or not
+	  # Consider that this link is valid if not empty or not 'http:#'
+	  # (default).
+	  # Only the backend should make use of the is_homepage_on_cvs value,
+	  # because and homepage can be on CVS with this flag off: this flag
+	  # is used to determine whether a CVSROOT must be created or not
 	  print '<br> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
 	}
       $i++;
     }
 
-  // Bug tracking
+  # Bug tracking
 
   if ($project->Uses("bugs")) {
     specific_makesep();
@@ -415,7 +414,7 @@ if ($project->Uses("patch") ||
   }
 
 
-  // Task Manager
+  # Task Manager
 
   if ($project->Uses("task")) {
     specific_makesep();
@@ -440,7 +439,7 @@ if ($project->Uses("patch") ||
   }
 
 
-  // Patch Manager
+  # Patch Manager
 
   if ($project->Uses("patch")) {
     specific_makesep();
@@ -468,7 +467,7 @@ if ($project->Uses("patch") ||
   $HTML->box1_bottom();
 }
 
-// ########################### News
+# ########################### News
 
 if ($project->Uses("news")) {
 
@@ -477,7 +476,7 @@ if ($project->Uses("news")) {
 	<td valign="top">
 	';
 
-  // ############################# Latest News
+  # ############################# Latest News
 
   print $HTML->box1_top(_("Latest News"));
   print news_show_latest($group_id,4,"true");
