@@ -1,47 +1,36 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: general.php,v 1.5 2004/02/12 00:28:55 toddy Exp $
-//
-// 
-// Copyright 1999-2000 (c) The SourceForge Crew
-// Copyright 2000-2003 (c) Free Software Foundation
-//                         Laurent Julliard, CodeX Team, Xerox
-// Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-//
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: general.php,v 1.8 2004/03/26 18:45:45 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
+#
+#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-/*
 
-Bug Tracker
-	By Tim Perdue, Sourceforge, 11/99
-	Heavy rewrite by Tim Perdue, April 2000
-	Very heavy rewrite by Laurent Julliard 2001, 2002, CodeX Team, Xerox
-        Heavy extended by GNU Savannah team + CERN
-*/
-
-// Return the file that should be included, according to the URL
-// requested. If the file start with ?, it's an index.
+# Return the file that should be included, according to the URL
+# requested. If the file start with ?, it's an index.
 function trackers_include() 
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_include() ';
-  // Keep the dirname only if it's admin
+  # Keep the dirname only if it's admin
   $dir = get_module_include_dir($GLOBALS['PHP_SELF'], 0, 1);
   if ($dir != "admin") 
     { 
@@ -56,7 +45,7 @@ function trackers_include()
   return $pre."../include/trackers_run/".$dir.basename($GLOBALS['PHP_SELF']);
 }
 
-// Generate URL arguments from a variable wether scalar or array
+# Generate URL arguments from a variable wether scalar or array
 function trackers_convert_to_url_arg($varname, $var)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_convert_to_url_arg($varname, $var)';
@@ -81,16 +70,16 @@ function trackers_header($params)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_header($params)';
   global $group_id,$is_bug_page,$DOCUMENT_ROOT,$advsrch;
 
-  //used so the search box will add the necessary element to the pop-up box
+  #used so the search box will add the necessary element to the pop-up box
   $is_bug_page=1;
 
-  //required params for site_project_header();
+  #required params for site_project_header();
   $params['group']=$group_id;
   $params['toptab']=ARTIFACT;
 	
   $project=project_get_object($group_id);
 
-  //needs to be turned  on
+  #needs to be turned  on
   if (ARTIFACT == "bugs"  && !$project->Uses("bugs") ||
       ARTIFACT == "support" &&  !$project->Uses("support") ||
       ARTIFACT == "task" && !$project->Uses("task") ||
@@ -107,16 +96,16 @@ function trackers_header_admin($params)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_header_admin($params)';
   global $group_id,$is_bug_page,$DOCUMENT_ROOT;
 
-  //used so the search box will add the necessary element to the pop-up box
+  #used so the search box will add the necessary element to the pop-up box
   $is_bug_page=1;
     
-  //required params for site_project_header();
+  #required params for site_project_header();
   $params['group']=$group_id;
   $params['toptab']='a'.ARTIFACT;
     
   $project=project_get_object($group_id);
     
-  // need to be turned on
+  # need to be turned on
   if (ARTIFACT == "bugs"  && !$project->Uses("bugs") ||
       ARTIFACT == "support" &&  !$project->Uses("support") ||
       ARTIFACT == "task" && !$project->Uses("task") ||
@@ -136,14 +125,14 @@ function trackers_footer($params)
 function trackers_init($group_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_init($group_id)';
-  // Set the global arrays for faster processing at init time
+  # Set the global arrays for faster processing at init time
   trackers_data_get_all_fields($group_id, true);
 }
 
 function trackers_report_init($group_id, $report_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_report_init($group_id, $report_id)';
-  // Set the global array with report information for faster processing
+  # Set the global array with report information for faster processing
   trackers_data_get_all_report_fields($group_id, $report_id, true);
 }
 
@@ -152,8 +141,8 @@ function trackers_list_all_fields($sort_func=false,$by_field_id=false)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_list_all_fields($sort_func=false,$by_field_id=false)';
   global $BF_USAGE_BY_ID, $BF_USAGE_BY_NAME, $AT_START;
 
-  // If it's the first element we fetch then apply the sort
-  // function  
+  # If it's the first element we fetch then apply the sort
+  # function  
   if ($AT_START)
     {
       if (!$sort_func)
@@ -163,11 +152,11 @@ function trackers_list_all_fields($sort_func=false,$by_field_id=false)
       $AT_START=false;
     }
 
-  // return the next bug field in the list. If the global
-  // bug field usage array is not set then set it the
-  // first time.
-  // by_field_id: true return the list of field id, false returns the
-  // list of field names
+  # return the next bug field in the list. If the global
+  # bug field usage array is not set then set it the
+  # first time.
+  # by_field_id: true return the list of field id, false returns the
+  # list of field names
 
   if ( list($key, $field_array) = each($BF_USAGE_BY_ID))
     {
@@ -175,7 +164,7 @@ function trackers_list_all_fields($sort_func=false,$by_field_id=false)
     }
   else
     {
-      // rewind internal pointer for next time
+      # rewind internal pointer for next time
       reset($BF_USAGE_BY_ID);
       reset($BF_USAGE_BY_NAME);
       $AT_START=true;
@@ -237,7 +226,7 @@ function trackers_field_display ($field_name,
       $output = trackers_field_label_display($field_name,$group_id,$break,$ascii);
     }
 
-  // display depends upon display type of this field
+  # display depends upon display type of this field
   switch (trackers_data_get_display_type($field_name))
     {
 
@@ -245,7 +234,7 @@ function trackers_field_display ($field_name,
       if ($ro)
 	{
 
-	  // if multiple selected values return a list of <br> separated values
+	  # if multiple selected values return a list of <br> separated values
 	  $arr = ( is_array($value) ? $value : array($value));
 	  for ($i=0;$i < count($arr); $i++)
 	    {
@@ -262,8 +251,8 @@ function trackers_field_display ($field_name,
 	}
       else
 	{
-	  // If it is a user name field (assigned_to, submitted_by) then make
-	  // sure to add the "None" entry in the menu 'coz it's not in the DB
+	  # If it is a user name field (assigned_to, submitted_by) then make
+	  # sure to add the "None" entry in the menu 'coz it's not in the DB
 	  if (trackers_data_is_username_field($field_name))
 	    {
 	      $show_none=true;
@@ -321,7 +310,7 @@ function trackers_field_date($field_name,$value='',$size=0,$maxlength=0,$ro=fals
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_date';
 
-  // value is formatted as Y-m-d
+  # value is formatted as Y-m-d
   list($year, $month, $day) = split("-", $value);
 
   if ($ro)
@@ -333,7 +322,7 @@ function trackers_field_date($field_name,$value='',$size=0,$maxlength=0,$ro=fals
       if (!$size || !$maxlength)
 	{ list($size, $maxlength) = trackers_data_get_display_size($field_name); }
 
-      // date part are missing, take the date of the day
+      # date part are missing, take the date of the day
       $today = localtime();
       if (!$day)
 	{ $day = ($today[3]); }
@@ -342,7 +331,7 @@ function trackers_field_date($field_name,$value='',$size=0,$maxlength=0,$ro=fals
       if (!$year)
 	{ $year = ($today[5]+1900); }      
 
-      // FIXME: order of year/day/month must be local specific
+      # FIXME: order of year/day/month must be local specific
       $html = calendar_selectbox("day", $day, $field_name.'_dayfd').calendar_selectbox("month", $month, $field_name.'_monthfd').' <input type="text" name="'.$field_name.'_yearfd" size="4" maxlenght="4" value="'.$year.'">';
     }
   return($html);
@@ -353,10 +342,10 @@ function trackers_multiple_field_date($field_name,$date_begin='',$date_end='',$s
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_multiple_field_date';
 
-  // CAUTION!!!! The Javascript below assumes that the date always appear
-  // in a field called 'bug_form'
+  # CAUTION!!!! The Javascript below assumes that the date always appear
+  # in a field called 'bug_form'
   
-  // FIXME: this is broken, should be made as trackers_field_date
+  # FIXME: this is broken, should be made as trackers_field_date
 
   if ($ro)
     if ($date_begin || $date_end)
@@ -487,8 +476,8 @@ function trackers_extract_field_list($post_method=true)
        field used by this project
   */
 
-  // Specific: it must build the date fields if it finds _dayfd, _monthfd
-  // or _yearfd, because date fields comes from 3 separated input.
+  # Specific: it must build the date fields if it finds _dayfd, _monthfd
+  # or _yearfd, because date fields comes from 3 separated input.
   $vfl = array();
   $date = array();
   if ($post_method)
@@ -498,14 +487,14 @@ function trackers_extract_field_list($post_method=true)
 	{
 	  if (preg_match("/^(.*)_(day|month|year)fd$/", $key, $found))
 	    {	      
-	      // Must build the date field key.
+	      # Must build the date field key.
 	      $field_name = $found[1];
 	      $field_name_part = $found[2];
 
-	      // We also must increment $day and $month, because the select
-	      // start from zero
+	      # We also must increment $day and $month, because the select
+	      # start from zero
 
-	      // get what we already have
+	      # get what we already have
 	      list($year, $month, $day) = split("-", $vfl[$field_name]);
 	      if ($field_name_part  == 'day')
 		{ $vfl[$field_name] = "$year-$month-".($val+1); }
@@ -520,7 +509,7 @@ function trackers_extract_field_list($post_method=true)
 	    }
 	  else
 	    {
-	      //dbg("Rejected key = ".$key." val = $val");
+	      #dbg("Rejected key = ".$key." val = $val");
 	    }
 	}
     }
@@ -531,11 +520,11 @@ function trackers_extract_field_list($post_method=true)
 	{
 	  if (preg_match("/^(.*)_(day|month|year)fd$/", $key, $found))
 	    {	      
-	      // Must build the date field key.
+	      # Must build the date field key.
 	      $field_name = $found[1];
 	      $field_name_part = $found[2];
 
-	      // get what we already have
+	      # get what we already have
 	      list($year, $month, $day) = split("-", $vfl[$field_name]);
 	      if ($field_name_part  == 'day')
 		{ $vfl[$field_name] = "$year-$month-$val"; }
@@ -574,11 +563,11 @@ function trackers_check_empty_fields($field_array)
   while ( list($key, $val) = each($field_array))
     {
       $is_empty = (trackers_data_is_select_box($key) ? ($val==100) : ($val==''));
-      // Only the field percent_complete is allowed to use the special value
-      // hundred.
-      // FIXME: maybe it should not use that value at all, however it would
-      // require one more database migration. Something that should indeed be
-      // done if at some point we feel the need for one more exception.
+      # Only the field percent_complete is allowed to use the special value
+      # hundred.
+      # FIXME: maybe it should not use that value at all, however it would
+      # require one more database migration. Something that should indeed be
+      # done if at some point we feel the need for one more exception.
       if ( $is_empty && !trackers_data_is_empty_ok($key) && $key != "percent_complete")
 	{
 	  
@@ -616,7 +605,7 @@ function trackers_canned_response_box ($group_id,$name='canned_response')
 function trackers_build_notification_matrix($user_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_build_notification_matrix($user_id)';
-  // Build the notif matrix indexed with roles and events labels (not id)
+  # Build the notif matrix indexed with roles and events labels (not id)
   $res_notif = trackers_data_get_notification_with_labels($user_id);
   while ($arr = db_fetch_array($res_notif))
     {
@@ -635,83 +624,83 @@ function trackers_check_notification($user_id, $role, $changes=false)
   if (!$arr_notif)
     { return true; }
 
-  //echo "==== DBG Checking Notif. for $user_id (role=$role)<br>";
+  #echo "==== DBG Checking Notif. for $user_id (role=$role)<br>";
   $user_name = user_getname($user_id);
 
-  //----------------------------------------------------------
-  // If it's a new bug only (changes is false) check the NEW_ITEM event and
-  // ignore all other events
+  #----------------------------------------------------------
+  # If it's a new bug only (changes is false) check the NEW_ITEM event and
+  # ignore all other events
   if ($changes==false)
     {
       if ($arr_notif[$role]['NEW_ITEM'])
 	{
-	  //echo "DBG NEW_ITEM notified<br>";
+	  #echo "DBG NEW_ITEM notified<br>";
 	  return true;
 	}
       else
 	{
-	  //echo "DBG No notification<br>";
+	  #echo "DBG No notification<br>";
 	  return false;
 	}
     }
 
-  //----------------------------------------------------------
-  //Check: I_MADE_IT  (I am the author of the change )
-  // Check this one first because if the user said no she doesn't want to be 
-  // aware of any of her change in this role and we can return immediately.
+  #----------------------------------------------------------
+  #Check: I_MADE_IT  (I am the author of the change )
+  # Check this one first because if the user said no she doesn't want to be 
+  # aware of any of her change in this role and we can return immediately.
   if (($user_id == user_getid()) && !$arr_notif[$role]['I_MADE_IT'])
     {
-      //echo "DBG Dont want to receive my own changes<br>";
+      #echo "DBG Dont want to receive my own changes<br>";
       return false;
     }
     
-  //----------------------------------------------------------
-  // Check :  NEW_COMMENT  A new followup comment is added 
+  #----------------------------------------------------------
+  # Check :  NEW_COMMENT  A new followup comment is added 
   if ($arr_notif[$role]['NEW_COMMENT'] && isset($changes['details']))
     {
-      //echo "DBG NEW_COMMENT notified<br>";
+      #echo "DBG NEW_COMMENT notified<br>";
       return true;
     }
 
-  //----------------------------------------------------------
-  //Check: NEW_FILE  (A new file attachment is added)
+  #----------------------------------------------------------
+  #Check: NEW_FILE  (A new file attachment is added)
   if ($arr_notif[$role]['NEW_FILE'] && isset($changes['attach']))
     {
-      //echo "DBG NEW_FILE notified<br>";
+      #echo "DBG NEW_FILE notified<br>";
       return true;
     }
   
-  //----------------------------------------------------------
-  //Check: CLOSED  (The bug is closed)
-  // Rk: this one has precedence over PSS_CHANGE. So notify even if PSS_CHANGE
-  // says no.
+  #----------------------------------------------------------
+  #Check: CLOSED  (The bug is closed)
+  # Rk: this one has precedence over PSS_CHANGE. So notify even if PSS_CHANGE
+  # says no.
   if ($arr_notif[$role]['CLOSED'] && ($changes['status_id']['add'] == 'Closed'))
     {
-      //echo "DBG CLOSED bug notified<br>";
+      #echo "DBG CLOSED bug notified<br>";
       return true;
     }
 
-  //----------------------------------------------------------
-  //Check: PSS_CHANGE  (Priority,Status,Severity changes)
+  #----------------------------------------------------------
+  #Check: PSS_CHANGE  (Priority,Status,Severity changes)
   if ($arr_notif[$role]['PSS_CHANGE'] && 
       (isset($changes['priority']) || isset($changes['status_id']) || isset($changes['severity'])) )
     {
-      //echo "DBG PSS_CHANGE notified<br>";
+      #echo "DBG PSS_CHANGE notified<br>";
       return true;
     }
 
 
-  //----------------------------------------------------------
-  // Check :  ROLE_CHANGE (I'm added to or removed from this role)
-  // Rk: This event is meanningless for Commenters. It also is for submitter but may be
-  // one day the submitter will be changeable by the project admin so test it.
-  // Rk #2: check this one at the end because it is the most CPU intensive and this
-  // event seldomly happens
+  #----------------------------------------------------------
+  # Check :  ROLE_CHANGE (I'm added to or removed from this role)
+  # Rk: This event is meanningless for Commenters. It also is for submitter but may be
+  # one day the submitter will be changeable by the project admin so test it.
+  # Rk #2: check this one at the end because it is the most CPU intensive and this
+  # event seldomly happens
   if ($arr_notif['SUBMITTER']['ROLE_CHANGE'] &&
       (($changes['submitted_by']['add'] == $user_name) || ($changes['submitted_by']['del'] == $user_name)) &&
       ($role == 'SUBMITTER') )
     {
-      //echo "DBG ROLE_CHANGE for submitter notified<br>";
+      #echo "DBG ROLE_CHANGE for submitter notified<br>";
       return true;
     }
 
@@ -719,7 +708,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
       (($changes['assigned_to']['add'] == $user_name) || ($changes['assigned_to']['del'] == $user_name)) &&
       ($role == 'ASSIGNEE') )
     {
-      //echo "DBG ROLE_CHANGE for role assignee notified<br>";
+      #echo "DBG ROLE_CHANGE for role assignee notified<br>";
       return true;
     }
 
@@ -735,36 +724,36 @@ function trackers_check_notification($user_id, $role, $changes=false)
     {
       if ($is_user_in_cc_changes)
 	{
-	  //echo "DBG ROLE_CHANGE for cc notified<br>";
+	  #echo "DBG ROLE_CHANGE for cc notified<br>";
 	  return true;
 	}
     }
     
-  //----------------------------------------------------------
-  //Check: CC_CHANGE  (CC_CHANGE is added or removed)
-  // check this right after because  role cahange for cc can contradict
-  // thee cc_change notification. If the role change on cc says no notification
-  // then it has precedence over a cc_change
+  #----------------------------------------------------------
+  #Check: CC_CHANGE  (CC_CHANGE is added or removed)
+  # check this right after because  role cahange for cc can contradict
+  # thee cc_change notification. If the role change on cc says no notification
+  # then it has precedence over a cc_change
   if ($arr_notif[$role]['CC_CHANGE'] && isset($changes['CC']))
     {
-      // it's enough to test role against 'CC' because if we are at that point
-      // it means that the role_change for CC was false or that role is not CC
-      // So if role is 'CC' and we are here it means that the user asked to not be
-      // notified on role_change as CC, unless other users are listed in the cc changes
+      # it's enough to test role against 'CC' because if we are at that point
+      # it means that the role_change for CC was false or that role is not CC
+      # So if role is 'CC' and we are here it means that the user asked to not be
+      # notified on role_change as CC, unless other users are listed in the cc changes
       if (($role != 'CC') || (($role == 'CC') && $are_anyother_user_in_cc_changes))
 	{
-	  //echo "DBG CC_CHANGE notified<br>";
+	  #echo "DBG CC_CHANGE notified<br>";
 	  return true; 
 	}
     }
 
 
-  //----------------------------------------------------------
-  //Check: CHANGE_OTHER  (Any changes not mentioned above)
-  // *** THIS ONE MUST ALWAYS BE TESTED LAST
+  #----------------------------------------------------------
+  #Check: CHANGE_OTHER  (Any changes not mentioned above)
+  # *** THIS ONE MUST ALWAYS BE TESTED LAST
     
-  // Delete all tested fields from the $changes array. If any remains then it
-  // means a notification must be sent
+  # Delete all tested fields from the $changes array. If any remains then it
+  # means a notification must be sent
   unset($changes['details']);
   unset($changes['attach']);
   unset($changes['priority']);
@@ -775,12 +764,12 @@ function trackers_check_notification($user_id, $role, $changes=false)
   unset($changes['submitted_by']);
   if ($arr_notif[$role]['ANY_OTHER_CHANGE'] && count($changes))
     {
-      //echo "DBG ANY_OTHER_CHANGE notified<br>";
+      #echo "DBG ANY_OTHER_CHANGE notified<br>";
       return true;
     }
 
-  // Sorry, no notification...
-  //echo "DBG No notification!!<br>";
+  # Sorry, no notification...
+  #echo "DBG No notification!!<br>";
   return false;
 }
 
@@ -791,16 +780,16 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
   $sql="SELECT assigned_to, submitted_by from ".ARTIFACT." WHERE bug_id='$item_id'";
   $res_as=db_query($sql);
 
-  // Rk: we store email addresses in a hash to make sure they are only
-  // stored once. Normally if an email is repeated several times sendmail
-  // would take care of it but I prefer taking care of it now.
-  // Same for user ids.
-  // We also use the user_ids hash to check if a user has already been selected for 
-  // notification. If so it is not necessary to check it again in another role.
+  # Rk: we store email addresses in a hash to make sure they are only
+  # stored once. Normally if an email is repeated several times sendmail
+  # would take care of it but I prefer taking care of it now.
+  # Same for user ids.
+  # We also use the user_ids hash to check if a user has already been selected for 
+  # notification. If so it is not necessary to check it again in another role.
   $addresses = array();
   $user_ids = array();
 
-  // check submitter notification preferences
+  # check submitter notification preferences
   $user_id = db_result($res_as,0,'submitted_by');
   if ($user_id != 100)
     {
@@ -810,7 +799,7 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 	}
     }
 
-  // check assignee  notification preferences
+  # check assignee  notification preferences
   $user_id = db_result($res_as,0,'assigned_to');
   if ($user_id != 100)
     {
@@ -820,7 +809,7 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 	}
     }
 
-  // check old assignee  notification preferences if assignee was just changed
+  # check old assignee  notification preferences if assignee was just changed
   $user_name = $changes['assigned_to']['del'];
   if ($user_name)
     {
@@ -832,12 +821,12 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 	}
     }
     
-  // check all CC 
-  // a) check all the people in the current CC list
-  // b) check the CC that has just been removed if any and see if she
-  // wants to be notified as well
-  // if the CC indentifier is an email address then notify in any case
-  // because this user has no personal setting
+  # check all CC 
+  # a) check all the people in the current CC list
+  # b) check the CC that has just been removed if any and see if she
+  # wants to be notified as well
+  # if the CC indentifier is an email address then notify in any case
+  # because this user has no personal setting
   $res_cc = trackers_data_get_cc_list($item_id);
   $arr_cc = array();
   if ($res_cc && (db_numrows($res_cc) > 0))
@@ -847,7 +836,7 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 	  $arr_cc[] = $row['email'];
 	}
     }
-  // Only one CC can be deleted at once so just append it to the list....
+  # Only one CC can be deleted at once so just append it to the list....
   $arr_cc[] = $changes['CC']['del'];
 
   while (list(,$cc) = each($arr_cc))
@@ -865,10 +854,10 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 	      $user_ids[$user_id] = true;
 	    }
 	}
-    } // while
+    } # while
 
 
-  // check all commenters
+  # check all commenters
   $res_com = trackers_data_get_commenters($item_id);
   if (db_numrows($res_com) > 0)
     {
@@ -882,18 +871,18 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 	}
     }
 
-  // build the final list of email addresses
+  # build the final list of email addresses
   reset($user_ids);
   while (list($user_id,) = each($user_ids))
     {
       if ($user_id)
-	{ // Dirty hack: for a reason need to be cleared out,
-	  // a user_id = 0 arrived here.
+	{ # Dirty hack: for a reason need to be cleared out,
+	  # a user_id = 0 arrived here.
 	  $addresses[user_getemail($user_id)] = true;
 	}
     }
 
-  // return an array with all the email addresses the notification must be sent to
+  # return an array with all the email addresses the notification must be sent to
   return (array_keys($addresses));
 
 }
@@ -934,13 +923,13 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
       $body .= "Submitted by: ".user_getrealname(db_result($result,0,'submitted_by'))."\n";      
       $body .= "On: ".format_date($sys_datefmt,db_result($result,0,'date'))."\n\n";
       
-      // All other regular fields now		 
+      # All other regular fields now		 
       $i=0;
       while ($field_name = trackers_list_all_fields())
 	{
 	  
-	  // if the field is a special field or if not used by his project 
-	  // then skip it. Otherwise print it in ASCII format.
+	  # if the field is a special field or if not used by his project 
+	  # then skip it. Otherwise print it in ASCII format.
 	  if (!trackers_data_is_special($field_name) &&
 	      trackers_data_is_used($field_name))
 	    {
@@ -959,36 +948,36 @@ function trackers_mail_followup($item_id,$more_addresses=false,$changes=false)
 	}
       $body .= "\n";
 						   
-      // Now display other special fields
-      // Summary first. It is a special field because it is both
-      // displayed in the
-      // title of the bug form and here as a text field
+      # Now display other special fields
+      # Summary first. It is a special field because it is both
+      # displayed in the
+      # title of the bug form and here as a text field
 
       $body .= "\n".trackers_field_display('summary', $group_id,
 					   db_result($result,0,'summary'),false,true,true,true).
 	 "\n\n".trackers_field_display('details', $group_id,
 				       db_result($result,0,'details'),false,true,true,true);
 
-      // Then output the history of bug details from newest to oldest
+      # Then output the history of bug details from newest to oldest
       $body .= "\n\n".format_item_details($item_id, $group_id, true);
 
-      // Then output the CC list
+      # Then output the CC list
       $body .= "\n\n".format_item_cc_list($item_id, $group_id, true);
 
-      // Then output the history of bug details from newest to oldest
+      # Then output the history of bug details from newest to oldest
       $body .= "\n\n".format_item_attached_files($item_id, $group_id, true);
 
-      // Finally output the message trailer
+      # Finally output the message trailer
       $body .= "\n\n\n\n\n\nFor detailed info, follow this link:";
       $body .= "\n<".$bug_href.">";
 
 
-      // See who is going to receive the notification.
-      // Plus append any other email 
-      // given at the end of the list.
+      # See who is going to receive the notification.
+      # Plus append any other email 
+      # given at the end of the list.
       $arr_addresses = trackers_build_notification_list($item_id,$group_id,$changes);
       $to = join(',',$arr_addresses);
-      $from = user_getrealname().' <noreply@'.$GLOBALS['sys_default_domain'].'>';
+      $from = user_getrealname(0,1).' <noreply@'.$GLOBALS['sys_default_domain'].'>';
       $subject = utils_unconvert_htmlspecialchars(db_result($result,0,'summary'));
 
       if ($more_addresses)
@@ -1100,7 +1089,7 @@ function trackers_add_cc($item_id,$group_id,$email,$comment)
   $changed = false;
   while (list(,$cc) = each($arr_email))
     {
-      // Add this cc only if not there already
+      # Add this cc only if not there already
       if (!trackers_exist_cc($item_id,$cc))
 	{
 	  $changed = true;
@@ -1126,8 +1115,8 @@ function trackers_delete_cc($group_id=false,$item_id=false,$item_cc_id=false)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_delete_cc($group_id=false,$item_id=false,$item_cc_id=false)';
   global $feedback,$ffeedback;
 
-  // If both bug_id and bug_cc_id are given make sure the cc belongs 
-  // to this bug (it's a bit paranoid but...)
+  # If both bug_id and bug_cc_id are given make sure the cc belongs 
+  # to this bug (it's a bit paranoid but...)
   if ($item_id)
     {
       $res1 = db_query("SELECT bug_id,email from ".ARTIFACT."_cc WHERE bug_cc_id='$item_cc_id'");
@@ -1138,7 +1127,7 @@ function trackers_delete_cc($group_id=false,$item_id=false,$item_cc_id=false)
 	}
     }
 
-  // Now delete the CC address
+  # Now delete the CC address
   $res2 = db_query("DELETE FROM ".ARTIFACT."_cc WHERE bug_cc_id='$item_cc_id'");
   if (!$res2)
     {
@@ -1163,10 +1152,10 @@ function trackers_delete_dependancy ($group_id, $item_id, $item_depends_on, $ite
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_delete_dependancy ($group_id, $item_id, $item_depends_on, $item_depends_on_artifact)';
   global $feedback,$ffeedback;
   
-  // Can be done only by at least technicians
-  // Note that is it possible to fake the system by providing a false group_id.
-  // But well, consequences would be small an it will be easy to identify
-  // the criminal.
+  # Can be done only by at least technicians
+  # Note that is it possible to fake the system by providing a false group_id.
+  # But well, consequences would be small an it will be easy to identify
+  # the criminal.
   
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'1'))
     {
@@ -1223,13 +1212,13 @@ function trackers_isvarany($var)
 }
 
 
-// Check is a sort criteria is already in the list of comma
-// separated criterias. If so invert the sort order, if not then
-// simply add it
+# Check is a sort criteria is already in the list of comma
+# separated criterias. If so invert the sort order, if not then
+# simply add it
 function trackers_add_sort_criteria($criteria_list, $order, $msort)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_add_sort_criteria($criteria_list, $order, $msort)';
-  //echo "<br>DBG \$criteria_list=$criteria_list,\$order=$order";
+  #echo "<br>DBG \$criteria_list=$criteria_list,\$order=$order";
 
   if ($criteria_list)
     {
@@ -1239,7 +1228,7 @@ function trackers_add_sort_criteria($criteria_list, $order, $msort)
 	{
 	  preg_match("/\s*([^<>]*)([<>]*)/", $attr,$match);
 	  list(,$mattr,$mdir) = $match;
-	  //echo "<br>DBG \$mattr=$mattr,\$mdir=$mdir";
+	  #echo "<br>DBG \$mattr=$mattr,\$mdir=$mdir";
 	  if ($mattr == $order)
 	    {
 	      if ( ($mdir == '>') || (!isset($mdir)) )
@@ -1261,7 +1250,7 @@ function trackers_add_sort_criteria($criteria_list, $order, $msort)
 	{ unset($arr); }
       if ( ($order == 'severity') || ($order == 'hours') || (trackers_data_is_date_field($order)) )
 	{
-	  // severity, effort and dates sorted in descending order by default
+	  # severity, effort and dates sorted in descending order by default
 	  $arr[] = $order.'<';
 	}
       else
@@ -1270,14 +1259,14 @@ function trackers_add_sort_criteria($criteria_list, $order, $msort)
 	}
     }
     
-  //echo "<br>DBG \$arr[]=".join(',',$arr);
+  #echo "<br>DBG \$arr[]=".join(',',$arr);
 
   return(join(',', $arr));	
 
 }
 
-// Transform criteria list to SQL query (+ means ascending
-// - is descending)
+# Transform criteria list to SQL query (+ means ascending
+# - is descending)
 function trackers_criteria_list_to_query($criteria_list)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_criteria_list_to_query($criteria_list)';
@@ -1287,8 +1276,8 @@ function trackers_criteria_list_to_query($criteria_list)
   return $criteria_list;
 }
 
-// Transform criteria list to readable text statement
-// $url must not contain the morder parameter
+# Transform criteria list to readable text statement
+# $url must not contain the morder parameter
 function trackers_criteria_list_to_text($criteria_list, $url)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_criteria_list_to_text($criteria_list, $url)';
@@ -1319,18 +1308,18 @@ function trackers_build_match_expression($field, &$to_match)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_build_match_expression($field, &$to_match)';
 
-  // First get the field type
+  # First get the field type
   $res = db_query("SHOW COLUMNS FROM ".ARTIFACT." LIKE '$field'");
   $type = db_result($res,0,'Type');
 
-  //echo "<br>DBG '$field' field type = $type";
+  #echo "<br>DBG '$field' field type = $type";
 
   if (preg_match('/text|varchar|blob/i', $type))
     {
 
-      // If it is sourrounded by /.../ the assume a regexp
-      // else transform into a series of LIKE %word%
-      if (preg_match('/\/(.*)\//', $to_match, $matches))
+      # If it is sourrounded by /.../ the assume a regexp
+      # else transform into a series of LIKE %word%
+      if (preg_match('/\/(.*)\#', $to_match, $matches))
 	$expr = "$field RLIKE '".$matches[1]."' ";
       else
 	{
@@ -1338,7 +1327,7 @@ function trackers_build_match_expression($field, &$to_match)
 	  reset($words);
 	  while ( list($i,$w) = each($words))
 	    {
-	      //echo "<br>DBG $i, $w, $words[$i]";
+	      #echo "<br>DBG $i, $w, $words[$i]";
 	      $words[$i] = "$field LIKE '%$w%'";
 	    }
 	  $expr = join(' AND ', $words);
@@ -1348,9 +1337,9 @@ function trackers_build_match_expression($field, &$to_match)
   else if (preg_match('/int/i', $type))
     {
 
-      // If it is sourrounded by /.../ the assume a regexp
-      // else assume an equality
-      if (preg_match('/\/(.*)\//', $to_match, $matches))
+      # If it is sourrounded by /.../ the assume a regexp
+      # else assume an equality
+      if (preg_match('/\/(.*)\#', $to_match, $matches))
 	{
 	  $expr = "$field RLIKE '".$matches[1]."' ";
 	}
@@ -1359,7 +1348,7 @@ function trackers_build_match_expression($field, &$to_match)
 	  $int_reg = '[+\-]*[0-9]+';
 	  if (preg_match("/\s*(<|>|>=|<=)\s*($int_reg)/", $to_match, $matches))
 	    {
-	      // It's < or >,  = and a number then use as is
+	      # It's < or >,  = and a number then use as is
 	      $matches[2] = (string)((int)$matches[2]);
 	      $expr = "$field ".$matches[1]." '".$matches[2]."' ";
 	      $to_match = $matches[1].' '.$matches[2];
@@ -1367,7 +1356,7 @@ function trackers_build_match_expression($field, &$to_match)
 	    } 
 	  else if (preg_match("/\s*($int_reg)\s*-\s*($int_reg)/", $to_match, $matches))
 	    {
-	      // it's a range number1-number2
+	      # it's a range number1-number2
 	      $matches[1] = (string)((int)$matches[1]);
 	      $matches[2] = (string)((int)$matches[2]);
 	      $expr = "$field >= '".$matches[1]."' AND $field <= '". $matches[2]."' ";
@@ -1376,7 +1365,7 @@ function trackers_build_match_expression($field, &$to_match)
 	    }
 	  else if (preg_match("/\s*($int_reg)/", $to_match, $matches))
 	    {
-	      // It's a number so use  equality
+	      # It's a number so use  equality
 	      $matches[1] = (string)((int)$matches[1]);
 	      $expr = "$field = '".$matches[1]."'";
 	      $to_match = $matches[1];
@@ -1384,7 +1373,7 @@ function trackers_build_match_expression($field, &$to_match)
 	    }
 	  else
 	    {
-	      // Invalid syntax - no condition
+	      # Invalid syntax - no condition
 	      $expr = '1';
 	      $to_match = '';
 	    }
@@ -1394,9 +1383,9 @@ function trackers_build_match_expression($field, &$to_match)
   else if (preg_match('/float/i', $type))
     {
 
-      // If it is sourrounded by /.../ the assume a regexp
-      // else assume an equality
-      if (preg_match('/\/(.*)\//', $to_match, $matches))
+      # If it is sourrounded by /.../ the assume a regexp
+      # else assume an equality
+      if (preg_match('/\/(.*)\#', $to_match, $matches))
 	{
 	  $expr = "$field RLIKE '".$matches[1]."' ";
 	}
@@ -1406,7 +1395,7 @@ function trackers_build_match_expression($field, &$to_match)
 
 	  if (preg_match("/\s*(<|>|>=|<=)\s*($flt_reg)/", $to_match, $matches))
 	    {
-	      // It's < or >,  = and a number then use as is
+	      # It's < or >,  = and a number then use as is
 	      $matches[2] = (string)((float)$matches[2]);
 	      $expr = "$field ".$matches[1]." '".$matches[2]."' ";
 	      $to_match = $matches[1].' '.$matches[2];
@@ -1414,7 +1403,7 @@ function trackers_build_match_expression($field, &$to_match)
 	    }
 	  else if (preg_match("/\s*($flt_reg)\s*-\s*($flt_reg)/", $to_match, $matches) )
 	    {
-	      // it's a range number1-number2
+	      # it's a range number1-number2
 	      $matches[1] = (string)((float)$matches[1]);
 	      $matches[2] = (string)((float)$matches[2]);
 	      $expr = "$field >= '".$matches[1]."' AND $field <= '". $matches[2]."' ";
@@ -1424,14 +1413,14 @@ function trackers_build_match_expression($field, &$to_match)
 	  else if (preg_match("/\s*($flt_reg)/", $to_match, $matches))
 	    {
 
-	      // It's a number so use  equality
+	      # It's a number so use  equality
 	      $matches[1] = (string)((float)$matches[1]);
 	      $expr = "$field = '".$matches[1]."'";
 	      $to_match = $matches[1];
 	    }
 	  else
 	    {
-	      // Invalid syntax - no condition
+	      # Invalid syntax - no condition
 	      $expr = '1';
 	      $to_match = '';
 	    }
@@ -1440,16 +1429,16 @@ function trackers_build_match_expression($field, &$to_match)
     }
   else
     {
-      // All the rest (???) use =
+      # All the rest (???) use =
       $expr = "$field = '$to_match'";
     }
 
-  //echo "<br>DBG expr to match for '$field' = $expr";
+  #echo "<br>DBG expr to match for '$field' = $expr";
   return ' ('.$expr.') ';
 
 }
 
-// function moved to data.
+# function moved to data.
 function trackers_delete_file($group_id=false,$item_id=false,$item_file_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_delete_file($group_id=false,$item_id=false,$item_file_id=false)';
