@@ -1,36 +1,26 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: notification_settings.php,v 1.8 2004/03/06 15:31:12 toddy Exp $
-//
-//
-// CodeX: Breaking Down the Barriers to Source Code Sharing inside Xerox
-// Copyright (c) Xerox Corporation, CodeX / CodeX Team, 2001-2002.
-// All Rights Reserved
-//
-//
-//  Copyright 2003 (c) Mathieu Roy <yeupou@gnu.org>
-//
-//
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-// Originally written by Laurent Julliard 2001, 2002, CodeX Team, Xerox
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: notification_settings.php,v 1.9 2004/03/13 18:22:06 yeupou Exp $
+#
+#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
+#
+#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 require_directory("project");
 
@@ -41,13 +31,13 @@ $is_admin_page='y';
  ================================================== */
 if (!$group_id)
 {
-  exit_no_group(); // need a group_id !!
+  exit_no_group(); # need a group_id !!
 }
 
 if (!user_isloggedin())
 {
-  // Must be at least logged in to set up your personal notification
-  // preference
+  # Must be at least logged in to set up your personal notification
+  # preference
   exit_permission_denied();
 }
 $is_user_a_member = user_ismember($group_id);
@@ -57,7 +47,7 @@ $is_user_a_member = user_ismember($group_id);
  ================================================== */
 
 $user_id = user_getid();
-// get notification roles
+# get notification roles
 $res_roles = trackers_data_get_notification_roles();
 $num_roles = db_numrows($res_roles);
 $i=0;
@@ -66,7 +56,7 @@ while ($arr = db_fetch_array($res_roles))
   $arr_roles[$i] = $arr; $i++;
 }
 
-// get notification events
+# get notification events
 $res_events = trackers_data_get_notification_events();
 $num_events = db_numrows($res_events);
 $i=0;
@@ -75,8 +65,8 @@ while ($arr = db_fetch_array($res_events))
   $arr_events[$i] = $arr; $i++;
 }
 
-// build the default notif settings in case the user has not yet defined her own
-// By default it's all 'yes'
+# build the default notif settings in case the user has not yet defined her own
+# By default it's all 'yes'
 for ($i=0; $i<$num_roles; $i++)
 {
   $role_id = $arr_roles[$i]['role_id'];
@@ -87,7 +77,7 @@ for ($i=0; $i<$num_roles; $i++)
     }
 }
 
-// Overwrite with user settings if any
+# Overwrite with user settings if any
 $res_notif = trackers_data_get_notification($user_id);
 while ($arr = db_fetch_array($res_notif))
 {
@@ -113,7 +103,7 @@ if ($submit)
       fb(_("- Update Failed").db_error());
     }
 
-} // end submit
+} # end submit
 
 
 /*  ==================================================
