@@ -1,45 +1,39 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: browse.php,v 1.26 2004/03/02 18:26:18 toddy Exp $
-//
-//  Copyright 1999-2000 (c) The SourceForge Crew
-//  Copyright 2000-2003 (c) Free Software Foundation
-//  Copyright 2001-2002 (c) Xerox Corporation, CodeX Team, All rights reserved
-//  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
-//	Bug Tracker originally by Tim Perdue 11/99
-//	Very Heavy rewrite by Laurent Julliard 2001, 2002, CodeX Team, Xerox
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: browse.php,v 1.27 2004/03/13 18:22:06 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
+#
+#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
-// Number of search criteria (boxes) displayed in one row
+
+# Number of search criteria (boxes) displayed in one row
 $fields_per_line=5;
 
-// Number of bugs displayed on screen in one chunk.
-// Default 50
+# Number of bugs displayed on screen in one chunk.
+# Default 50
 if (!$chunksz)
 { $chunksz = 50; }
 
-// Make sure offset is defined and has a correct value
+# Make sure offset is defined and has a correct value
 if (!$offset || $offset < 0)
 { $offset=0; }
 
@@ -47,7 +41,7 @@ if (!$offset || $offset < 0)
 /* ==================================================
     Get the list of bug fields used in the form (they are in the URL - GET method)
     and then build the preferences array accordingly
-    Exclude the group_id parameter// Extract the list of bug fields
+    Exclude the group_id parameter# Extract the list of bug fields
  ================================================== */
 
 $prefs = trackers_extract_field_list(false);
@@ -65,11 +59,11 @@ while (list($field,$value_id) = each($prefs))
     {
       unset($prefs[$field]);
       $prefs[$field][] = $value_id;
-      //echo '<br> DBG Setting $prefs['.$field.'] [] = '.$value_id;
+      #echo '<br> DBG Setting $prefs['.$field.'] [] = '.$value_id;
     }
   else
     {
-      //echo '<br> DBG $prefs['.$field.'] = ('.implode(',',$value_id).')';
+      #echo '<br> DBG $prefs['.$field.'] = ('.implode(',',$value_id).')';
     }
 
   if (trackers_data_is_date_field($field))
@@ -78,7 +72,7 @@ while (list($field,$value_id) = each($prefs))
 	{
 	  $field_end = $field.'_end';
 	  $prefs[$field_end] = $$field_end;
-	  //echo '<br> DBG Setting $prefs['.$field.'_end]= '.$prefs[$field.'_end'];
+	  #echo '<br> DBG Setting $prefs['.$field.'_end]= '.$prefs[$field.'_end'];
 	}
       else
 	{
@@ -86,7 +80,7 @@ while (list($field,$value_id) = each($prefs))
 	  $prefs[$field_op] = $$field_op;
 	  if (!$prefs[$field_op])
 	    $prefs[$field_op] = '>';
-	  //echo '<br> DBG Setting $prefs['.$field.'_op]= '.$prefs[$field.'_op'];
+	  #echo '<br> DBG Setting $prefs['.$field.'_op]= '.$prefs[$field.'_op'];
 	}
     }
 }
@@ -100,8 +94,8 @@ while (list($field,$value_id) = each($prefs))
    $order = last sort criteria selected in the UI
    $msort = 1 if multicolumn sort activated.
   ================================================== */
-//echo "<br>DBG \$morder at top: [$morder ]";
-//   if morder not defined then reuse the one in preferences
+#echo "<br>DBG \$morder at top: [$morder ]";
+#   if morder not defined then reuse the one in preferences
 if (user_isloggedin() && !isset($morder))
 {
   $morder = user_get_preference('bug_browse_order'.$group_id);
@@ -112,12 +106,12 @@ if (isset($order))
 
   if ($order != '')
     {
-      // Add the criteria to the list of existing ones
+      # Add the criteria to the list of existing ones
       $morder = trackers_add_sort_criteria($morder, $order, $msort);
     }
   else
     {
-      // reset list of sort criteria
+      # reset list of sort criteria
       $morder = '';
     }
 }
@@ -137,7 +131,7 @@ if (isset($morder))
     }
 }
 
-//echo "<BR> DBG Order by = $order_by";
+#echo "<BR> DBG Order by = $order_by";
 
 
 /* ==================================================
@@ -158,7 +152,7 @@ if (user_isloggedin())
     }
 }
 
-// If still not defined then force it to system 'Default' report
+# If still not defined then force it to system 'Default' report
 if (!$report_id)
 { $report_id=100; }
 
@@ -187,8 +181,8 @@ if (!$set)
 	  $pref_arr = explode('&',substr($custom_pref,1));
 	  while (list(,$expr) = each($pref_arr))
 	    {
-	      // Extract left and right parts of the assignment
-	      // and remove the '[]' array symbol from the left part
+	      # Extract left and right parts of the assignment
+	      # and remove the '[]' array symbol from the left part
 	      list($field,$value_id) = explode('=',$expr);
 	      $field = str_replace('[]','',$field);
 	      if ($field == 'advsrch')
@@ -202,7 +196,7 @@ if (!$set)
 	      else
 		$prefs[$field][] = $value_id;
 
-	      //echo '<br>DBG restoring prefs : $prefs['.$field.'] []='.$value_id;
+	      #echo '<br>DBG restoring prefs : $prefs['.$field.'] []='.$value_id;
 	    }
 	  $set='custom';
 
@@ -232,9 +226,9 @@ if ($set=='my')
 else if ($set=='custom')
 {
 
-  // Get the list of bug fields used in the form (they are in the URL - GET method)
-  // and then build the preferences array accordingly
-  // Exclude the group_id parameter
+  # Get the list of bug fields used in the form (they are in the URL - GET method)
+  # and then build the preferences array accordingly
+  # Exclude the group_id parameter
   reset($prefs);
   while (list($field,$arr_val) = each($prefs))
     {
@@ -243,8 +237,8 @@ else if ($set=='custom')
 	  $pref_stg .= '&'.$field.'[]='.$value_id;
 	}
 
-      // build part of the HTML title of this page for more friendly bookmarking
-      // Do not add the criteria in the header if value is "Any"
+      # build part of the HTML title of this page for more friendly bookmarking
+      # Do not add the criteria in the header if value is "Any"
       if ($value_id != 0)
 	{
 	  $hdr .= ' By '.trackers_data_get_label($field).': '.
@@ -258,14 +252,14 @@ else if ($set=='custom')
 
   if ($pref_stg != user_get_preference('bug_brow_cust'.$group_id))
     {
-      //echo "<br> DBG setting pref = $pref_stg";
+      #echo "<br> DBG setting pref = $pref_stg";
       user_set_preference('bug_brow_cust'.$group_id,$pref_stg);
     }
 
 }
 else
 {
-  // Open bugs - backwards compat can be removed 9/10
+  # Open bugs - backwards compat can be removed 9/10
   $prefs['status_id'][]=1;
 }
 
@@ -280,7 +274,7 @@ if (!isset($msort))
 { $msort = 0; }
 while ($field = trackers_list_all_fields())
 {
-  // the select boxes for the bug DB search first
+  # the select boxes for the bug DB search first
   if (trackers_data_is_showed_on_query($field) &&
       trackers_data_is_select_box($field) )
     {
@@ -292,7 +286,7 @@ while ($field = trackers_list_all_fields())
    Start building the SQL query (select and where clauses)
   ================================================== */
 
-// Force the selection of severity because it is always shown as color code
+# Force the selection of severity because it is always shown as color code
 $col_list = $lbl_list = array();
 $select_count = 'SELECT count(*) AS count ';
 $select = 'SELECT '.ARTIFACT.'.priority ';
@@ -302,27 +296,27 @@ if (!$pv)
 { $limit = " LIMIT $offset,$chunksz";}
 
 
-// prepare the where clause with the selection criteria given by the user
+# prepare the where clause with the selection criteria given by the user
 reset($prefs);
 while (list($field,$value_id) = each($prefs))
 {
 
-  // If the criteria is not in the field showed on query screen then
-  // skip it. This is a sanity check to make sure that the SQL
-  // query we run actually matches the displayed search criteria
+  # If the criteria is not in the field showed on query screen then
+  # skip it. This is a sanity check to make sure that the SQL
+  # query we run actually matches the displayed search criteria
   if (!trackers_data_is_showed_on_query($field))
     { continue; }
 
   if (trackers_data_is_select_box($field) && !trackers_isvarany($prefs[$field]) )
     {
 
-      // Only select box criteria to where clause if argument is not ANY
+      # Only select box criteria to where clause if argument is not ANY
       $where .= ' AND '.ARTIFACT.'.'.$field.' IN ('.implode(',',$prefs[$field]).') ';
 
     } else if (trackers_data_is_date_field($field) && $prefs[$field][0])
       {
 
-	// transform a date field into a unix time and use <, > or =
+	# transform a date field into a unix time and use <, > or =
 	list($time,$ok) = utils_date_to_unixtime($prefs[$field][0]);
 
 	if ($advsrch)
@@ -340,7 +334,7 @@ while (list($field,$value_id) = each($prefs))
 	  {
 
 	    $operator = $prefs[$field.'_op'][0];
-	    // '=' means that day between 00:00 and 23:59
+	    # '=' means that day between 00:00 and 23:59
 	    if ($operator == '=')
 	      {
 		$time_end = mktime(23, 59, 59, $month, $day, $year);
@@ -352,14 +346,14 @@ while (list($field,$value_id) = each($prefs))
 	      }
 	  }
 
-	// Always exclude undefined dates (0)
+	# Always exclude undefined dates (0)
 	$where .= ' AND '.ARTIFACT.'.'.$field." <> 0 ";
 
       } else if ((trackers_data_is_text_field($field) || trackers_data_is_text_area($field))
 		 && $prefs[$field][0])
 	{
 
-	  // It's a text field accept. Process INT or TEXT,VARCHAR fields differently
+	  # It's a text field accept. Process INT or TEXT,VARCHAR fields differently
 	  $where .= ' AND '.trackers_build_match_expression($field, $prefs[$field][0]);
 	}
 }
@@ -379,7 +373,7 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
       continue;
     }
 
-  // beginning of a new row
+  # beginning of a new row
   if ($ib % $fields_per_line == 0)
     {
       $align = ($pv ? "left" : "center");
@@ -388,11 +382,11 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
     }
 
   $labels .= '<td class="preinput">'.trackers_data_get_label($field).' :</td>';
-     // Duh, it never work with konqueror and many others browsers
-     // and basically, if "category" is unclear, the name of the field
-     // must be change
-     //     ($pv ? '':help_button('browse_bug_query_field',$field)).
-  //     '</td>';
+     # Duh, it never work with konqueror and many others browsers
+     # and basically, if "category" is unclear, the name of the field
+     # must be change
+     #     ($pv ? '':help_button('browse_bug_query_field',$field)).
+  #     '</td>';
 
   $boxes .= '<TD><FONT SIZE="-1">';
 
@@ -406,7 +400,7 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
 
     } else if (trackers_data_is_date_field($field) ){
 
-      $load_cal = true; // We need to load the Javascript Calendar
+      $load_cal = true; # We need to load the Javascript Calendar
       if ($advsrch)
 	$boxes .= trackers_multiple_field_date($field,$prefs[$field][0],
 					       $prefs[$field.'_end'][0],0,0,$pv);
@@ -426,7 +420,7 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
 
   $ib++;
 
-  // end of this row
+  # end of this row
   if ($ib % $fields_per_line == 0)
     {
       $html_select .= $labels.'</TR>'.$boxes.'</TR>';
@@ -435,7 +429,7 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
 
 }
 
-// Make sure the last few cells are in the table
+# Make sure the last few cells are in the table
 if ($labels)
 {
   $html_select .= $labels.'</TR>'.$boxes.'</TR>';
@@ -461,15 +455,15 @@ while ( $field = trackers_list_all_fields(cmp_place_result))
 
   if ( trackers_data_is_username_field($field))
     {
-      // user names requires some special processing to display the username
-      // instead of the user_id
+      # user names requires some special processing to display the username
+      # instead of the user_id
       $select .= ",user_$field.user_name AS $field";
       $from .= ",user user_$field";
       $where .= " AND user_$field.user_id=".ARTIFACT.".$field ";
     }
   else
     {
-      // otherwise just select this column as is
+      # otherwise just select this column as is
       $select .= ",".ARTIFACT.".$field";
     }
 
@@ -489,8 +483,8 @@ $totalrows = db_result($result_count,0,'count');
 
 $sql = "$select $from $where $order_by $limit";
 $result=db_query($sql);
-//echo "<br> DBG SQL = $sql";
-//exit 0;
+#echo "<br> DBG SQL = $sql";
+#exit 0;
 
 
 /* ==================================================
@@ -518,7 +512,7 @@ echo '    <FORM ACTION="'.$PHP_SELF .'" METHOD="GET" NAME="bug_form">
           <INPUT TYPE="HIDDEN" NAME="msort" VALUE="'.$msort.'">
           <h3>'._("Browse").' ';
 
-// Show the list of available bug reports kind
+# Show the list of available bug reports kind
 if (!$pv)
 {
   $res_report = trackers_data_get_reports($group_id,user_getid());
@@ -527,7 +521,7 @@ if (!$pv)
   printf(_("with the %s query form"), html_build_select_box($res_report,$box_name,$report_id,true,'Basic'));
 }
 
-// Start building the URL that we use to for hyperlink in the form
+# Start building the URL that we use to for hyperlink in the form
 $url = $GLOBALS['sys_home'].ARTIFACT."/?group_id=$group_id&func=browse&set=$set&msort=$msort";
 if ($set == 'custom')
      $url .= $pref_stg;
@@ -537,7 +531,7 @@ if ($set == 'custom')
 $url_nomorder = $url;
 $url .= "&morder=$morder";
 
-// Build the URL for alternate Search
+# Build the URL for alternate Search
 if ($advsrch)
 {
   $url_alternate_search = str_replace('advsrch=1','advsrch=0',$url);
@@ -549,7 +543,7 @@ else
   $text = _("Advanced Search");
 }
 
-// Select 'list form' or 'select' form
+# Select 'list form' or 'select' form
 if (!$pv)
 {
   if ($advsrch)
@@ -563,7 +557,7 @@ if (!$pv)
   printf(' '._("and %s selection."), '<select name="advsrch"><option value="0"'.$advsrch_0.'>'._("Simple").'</option><option value="1"'.$advsrch_1.'>'._("Multiple").'</option></select>');
 }
 
-// End the form type selection
+# End the form type selection
 echo '<input value="'._("Apply").'" name="go_report" type="submit">';
 echo '</h3>';
 
@@ -589,7 +583,7 @@ $numrows = db_numrows($result);
 if ($result && $numrows > 0)
 {
 
-  // Build the sorting header messages
+  # Build the sorting header messages
   if ($morder)
     {
       $order_statement = _("sorted by:")." ".trackers_criteria_list_to_text($morder, $url_nomorder);
