@@ -1,32 +1,29 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: detail.php,v 1.24 2004/02/12 20:43:44 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation
-//                          Laurent Julliard, CodeX Team, Xerox
-//
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: detail.php,v 1.26 2004/03/14 18:40:45 yeupou Exp $
+#
+# Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
+#
+#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
  
 trackers_header(array ('title'=>_("Item Detail:").' '.$item_id));
 
@@ -38,7 +35,7 @@ $result=db_query($sql);
 
 if (db_numrows($result) > 0) 
 {
-  // Start the form.
+  # Start the form.
 
   print '<h2>['.ARTIFACT.' #'.$item_id.'] '.db_result($result,0,'summary').'</h2>';
 
@@ -57,22 +54,22 @@ if (db_numrows($result) > 0)
   print '</tr>';
   print '<tr><td colspan="'.$fields_per_line.'">&nbsp</td></tr>';
 
-  // Print special fields
+  # Print special fields
 
   $i=0;
   while ( $field_name = trackers_list_all_fields() ) 
     {
 
 
-      // if the field is a special field (except summary and details) 
-      // or if not used by this project  then skip it.
+      # if the field is a special field (except summary and details) 
+      # or if not used by this project  then skip it.
       if ( (!trackers_data_is_special($field_name)  || $field_name=='summary' || $field_name=='details') &&
 	   trackers_data_is_used($field_name) ) 
 	{
 				   
-	  // display the bug field
-	  // if field size is greatest than max_size chars then force it to
-	  // appear alone on a new line or it won't fit in the page
+	  # display the bug field
+	  # if field size is greatest than max_size chars then force it to
+	  # appear alone on a new line or it won't fit in the page
 	  $field_value = db_result($result,0,$field_name);
 	  list($sz,) = trackers_data_get_display_size($field_name);
 
@@ -100,7 +97,7 @@ if (db_numrows($result) > 0)
   print '</table>';
 
 
-  // Comments 
+  # Comments 
 
   print '<h3>'._("Add A Comment:").'</h3>';
   printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
@@ -127,7 +124,22 @@ if (db_numrows($result) > 0)
 
   print '<p>&nbsp;</p>';
 
-  // Mail notification
+  # ################################ Attached Files
+
+  print '<h3>'._("Attached Files").'</h3>';
+  
+  print '<font class="preinput"> '._("Attach File:").'</font><br>
+      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
+      <br>
+      <font class="preinput">'._("File Description:").'</font><br>
+      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
+      </p><p>';
+	  
+  show_item_attached_files($item_id,$group_id);
+
+  print '</p>&nbsp;<p>';
+
+  # ################################ Mail notification
   
   print '<h3>'._("Mail Notification Carbon-Copy List").'</h3>';
 
@@ -142,23 +154,8 @@ if (db_numrows($result) > 0)
   show_item_cc_list($item_id, $group_id);
     
   print '<p>&nbsp;</p>';
-  
-  // Attached files
 
-  print '<h3>'._("Attached Files").'</h3>';
-  print '<font class="preinput"> '._("Attach File:").'</font><br>
-      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="60">
-      <br>
-      <font class="preinput">'
-      ._("File Description:").'</font><br>
-      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
-      </p><p>';
-
-  show_item_attached_files($item_id,$group_id);
-
-  print '<p>&nbsp;</p>';
-
-  // Dependancies 
+  # Dependancies 
 
   print '<h3>'._("Dependencies").'</h3>';
 
@@ -170,7 +167,7 @@ if (db_numrows($result) > 0)
 
   print '<p>&nbsp;</p>';
 
-  //  Submit 
+  #  Submit 
 
   print '<p align="center">
 	  <input type="submit" name="submit" class="bold" value="'._("Submit Changes").'">
@@ -179,7 +176,7 @@ if (db_numrows($result) > 0)
 
 
 
-  // History 
+  # History 
 
   print '<p>&nbsp;</p><p>&nbsp;</p>';
   show_item_history($item_id,$group_id);
