@@ -1,42 +1,40 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: index.php,v 1.25 2004/03/06 16:53:35 toddy Exp $
-//
-//
-//  Copyright 1999-2000 (c) The SourceForge Crew
-//  Copyright 2000-2003 (c) Free Software Foundation
-//                          Laurent Julliard, CodeX Team, Xerox
-//
-//  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at-gna.org>
-//
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: index.php,v 1.27 2004/03/14 18:40:45 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
+#
+#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at-gna.org>
+#
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 if ($item_id && !$group_id)
 {
-  // If the group information is missing, try to guess it
-  // from the item_id given
+  # If the group information is missing, try to guess it
+  # from the item_id given
   $group_id = trackers_data_get_item_group($item_id);
 }
 
 if ($group_id)
 {
-  // Initialize the global data structure before anything else
+  # Initialize the global data structure before anything else
   trackers_init($group_id);
 
   $project=project_get_object($group_id);
@@ -48,7 +46,7 @@ if ($group_id)
 
     case 'search' :
       {
-	// Form to do a search on the item database
+	# Form to do a search on the item database
 
 	include '../include/trackers_run/search.php';
 	break;
@@ -56,8 +54,8 @@ if ($group_id)
 
     case 'browse' :
       {
-	// Browse thru the bug database
-	// (it also the Default)
+	# Browse thru the bug database
+	# (it also the Default)
 
 	include '../include/trackers_run/browse.php';
 	break;
@@ -65,7 +63,7 @@ if ($group_id)
 
     case 'additem' :
       {
-	// Form to add new item
+	# Form to add new item
 
 	include '../include/trackers_run/add.php';
 	break;
@@ -73,8 +71,8 @@ if ($group_id)
 
     case 'detailitem' :
       {
-	// Show a bug already in the database, permitting to add comment
-	// or even modify.
+	# Show a bug already in the database, permitting to add comment
+	# or even modify.
 
 	if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2'))
 	  {
@@ -91,18 +89,18 @@ if ($group_id)
 
     case 'postadditem' :
       {
-	// Actually add in the database what was filled in the form
+	# Actually add in the database what was filled in the form
 
-	// Get the list of bug fields used in the form
+	# Get the list of bug fields used in the form
 	$vfl = trackers_extract_field_list();
 
-	// Data control layer
+	# Data control layer
 	$item_id=trackers_data_create_item($group_id,$vfl);
 
 	if ($item_id)
 	  {
 
-	    // Attach new file if there is one
+	    # Attach new file if there is one
 	    if ($input_file != "none" && $input_file)
 	      {
 		trackers_attach_file($item_id,
@@ -113,7 +111,7 @@ if ($group_id)
 				     $input_file_size,
 				     $file_description);
 	      }
-	    // Add new cc if any
+	    # Add new cc if any
 	    if ($add_cc && user_isloggedin())
 	      {
 		trackers_add_cc($item_id,
@@ -123,18 +121,18 @@ if ($group_id)
 	      }
 
 
-	    // send an email to notify the user of the bug update
+	    # send an email to notify the user of the bug update
 	    list($address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 0);
 	    trackers_mail_followup($item_id, $address);
 
 	  }
 	else
 	  {
-	    // Some error occurred
+	    # Some error occurred
 	    fb(_("Missing parameters, nothing added."), 0);
 	  }
 
-	// show browse item page
+	# show browse item page
 	include '../include/trackers_run/browse.php';
 
 
@@ -144,15 +142,15 @@ if ($group_id)
     case 'postmoditem' :
       {
 
-	// Update a bug already in the database, reserved to item techn.
-	// or manager.
+	# Update a bug already in the database, reserved to item techn.
+	# or manager.
 
 	if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2'))
 	  {
 	    dbg("Techn. or Manager rights, make an update on almost every fields.");
 
-	    // Special case: we may be searching for an item, in that case
-	    // reprint the same page, plus search results.
+	    # Special case: we may be searching for an item, in that case
+	    # reprint the same page, plus search results.
 	    if ($depends_search || $reassign_change_project_search)
 	      {
 		if ($depends_search)
@@ -170,10 +168,10 @@ if ($group_id)
 		break;
 	      }
 
-	    // Get the list of bug fields used in the form
+	    # Get the list of bug fields used in the form
 	    $vfl = trackers_extract_field_list();
 
-	    //data control layer
+	    #data control layer
 	    $additional_addresses = "";
 	    $changed = trackers_data_handle_update($group_id,
 						   $item_id,
@@ -187,7 +185,7 @@ if ($group_id)
 						   $additional_addresses);
 
 
-	    // Attach new file if there is one
+	    # Attach new file if there is one
 	    if ($input_file != "none" && $input_file)
 	      {
 		$changed |= trackers_attach_file($item_id,
@@ -200,7 +198,7 @@ if ($group_id)
 						 $changes);
 	      }
 
-	    // Add new cc if any
+	    # Add new cc if any
 	    if ($add_cc)
 	      {
 		$changed |= trackers_add_cc($item_id,
@@ -212,7 +210,7 @@ if ($group_id)
 
 	    if ($changed)
 	      {
-		// Check if we're supposed to send all modifications to an address
+		# Check if we're supposed to send all modifications to an address
 		list($address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
 		if ($sendall == 1)
 		  {
@@ -225,10 +223,10 @@ if ($group_id)
 
 	      }
 
-	    // Finally handle reassignation of an entry. Why so late?
-	    // Because all the information entered by someone reassigning
-	    // the bug must be in the original report, and will be duplicated
-	    // in the new one.
+	    # Finally handle reassignation of an entry. Why so late?
+	    # Because all the information entered by someone reassigning
+	    # the bug must be in the original report, and will be duplicated
+	    # in the new one.
 	    if ($reassign_change_project || ($reassign_change_artifact && ($reassign_change_artifact != ARTIFACT)))
 	      {
 		dbg("reassign item: reassign_change_project:$reassign_change_project, reassign_change_artifact:$reassign_change_artifact, ARTIFACT:".ARTIFACT);
@@ -245,16 +243,16 @@ if ($group_id)
 
     case 'postaddcomment' :
       {
-	// Add a comment to a bug already in the database,
-	// these are the only changes an non member can make
+	# Add a comment to a bug already in the database,
+	# these are the only changes an non member can make
 
-	// Add a new comment if there is one
+	# Add a new comment if there is one
 	if ($details != '')
 	  {
-	    // For none project members force the comment type to None (100)
+	    # For none project members force the comment type to None (100)
 	    trackers_data_add_history('details',htmlspecialchars($details),'',$item_id,100);
 
-            // YPE fix to trigger notifications in case of non member
+            # YPE fix to trigger notifications in case of non member
             $changes['details']['add'] = stripslashes($details);
             $changes['details']['type'] = 'None';
             $changed = true;
@@ -262,8 +260,8 @@ if ($group_id)
 	    fb(_("Comment added to item."));
 	  }
 
-	// Attach new file if there is one
-	if ($input_file != "none")
+	# Attach new file if there is one
+	if ($input_file != "none" && $input_file)
 	  {
 	    trackers_attach_file($item_id,
 				 $group_id,
@@ -273,7 +271,7 @@ if ($group_id)
 				 $input_file_size,
 				 $file_description);
 	  }
-	    // Add new cc if any, only accepted from logged in users.
+	    # Add new cc if any, only accepted from logged in users.
 	if ($add_cc && user_isloggedin())
 	  {
 	    trackers_add_cc($item_id,
@@ -294,14 +292,14 @@ if ($group_id)
 
     case 'delete_file' :
       {
-	// Remove an attached file
+	# Remove an attached file
 
 	if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2'))
 	  {
 	    trackers_data_delete_file($group_id,$item_id,$item_file_id);
 
-	    // unset item_id var to make sure that it doesn;t
-	    // impact the next bug query.
+	    # unset item_id var to make sure that it doesn;t
+	    # impact the next bug query.
 	    unset($item_id);
 	    unset($HTTP_GET_VARS['item_id']);
 	    include '../include/trackers_run/browse.php';
@@ -315,7 +313,7 @@ if ($group_id)
 
     case 'delete_cc' :
       {
-	// Remove a person from the Cc: list of a bug
+	# Remove a person from the Cc: list of a bug
 
 	$changed = trackers_delete_cc($group_id,$item_id,$item_cc_id,$changes);
 
@@ -331,8 +329,8 @@ if ($group_id)
 	      }
 	  }
 
-	// unset trackers_id var to make sure that it doesn;t
-	// impact the next bug query.
+	# unset trackers_id var to make sure that it doesn;t
+	# impact the next bug query.
 	unset($item_id);
 	unset($HTTP_GET_VARS['item_id']);
 	include '../include/trackers_run/browse.php';
@@ -342,7 +340,7 @@ if ($group_id)
 
     case 'delete_dependancy' :
       {
-	// Remove a dependancy
+	# Remove a dependancy
 
 	$changed = trackers_delete_dependancy($group_id,
 					      $item_id,
@@ -351,7 +349,7 @@ if ($group_id)
 
 	if ($changed)
 	  {
-	    // check if we're supposed to send all modifications to an address
+	    # check if we're supposed to send all modifications to an address
 	    list($address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
 	    if ($sendall == 1)
 	      {
@@ -359,8 +357,8 @@ if ($group_id)
 	      }
 	  }
 
-	// unset trackers_id var to make sure that it doesn;t
-	// impact the next bug query.
+	# unset trackers_id var to make sure that it doesn;t
+	# impact the next bug query.
 	unset($item_id);
 	unset($HTTP_GET_VARS['item_id']);
 	include '../include/trackers_run/browse.php';
@@ -377,7 +375,7 @@ if ($group_id)
 
     case 'modfilters' :
       {
-      // Modification of the filters (query form)
+      # Modification of the filters (query form)
 
 	if (user_isloggedin())
 	  {
@@ -403,7 +401,7 @@ if ($group_id)
 
     default :
       {
-	// Browse thru the bug database
+	# Browse thru the bug database
 
 	include '../include/trackers_run/browse.php';
 	break;
