@@ -2,11 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: user.php,v 1.11 2004/02/15 12:40:38 yeupou Exp $
+# $Id: user.php,v 1.13 2004/03/26 18:45:45 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
+#  Copyright 2004      (c) ...
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -224,11 +226,20 @@ function user_getname($user_id=0, $getrealname=0)
 }
 
 
-function user_getid()
+function user_getid($username=0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':user_getid()';
-  global $G_USER;
-  return ($G_USER?$G_USER['user_id']:0);
+  if (!$username) 
+    {
+      # No username, return info for the current user
+      global $G_USER;
+      return ($G_USER?$G_USER['user_id']:0);
+    }
+  else 
+    {
+      $result = db_query("SELECT user_id FROM user WHERE user_name='$username'");
+      return db_result($result,0,"user_id");
+    }
 }
 
 function user_exists($user_id) 
@@ -245,10 +256,15 @@ function user_exists($user_id)
 #quick hack - this entire library needs a rewrite similar to groups library
 # yeupou@gnu.org Please no! rewrite both the library and this one, and 
 # please avoid object things without discussing about it on savannah-dev
-function user_getrealname($user_id=0)
+function user_getrealname($user_id=0, $rfc822_compliant=0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':user_getrealname($user_id=0)';
-  return user_getname($user_id, 1);
+  $ret = user_getname($user_id, 1);
+  # rfc822 requires some characters to be escaped. We usually care about this
+  # compliance only in email headers.
+  if ($rfc822_compliant && ereg("\.|\,|\@|\/|\\|\||\;|\!", $ret))
+    { $ret = "\"$ret\""; }
+  return $ret;
 }
 
 function user_getemail($user_id)
