@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.57 2004/03/07 12:51:01 yeupou Exp $
+# $Id: utils.php,v 1.60 2004/03/28 18:17:44 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -363,10 +363,10 @@ function utils_make_links ($data='',$group_id = 0)
       $line = eregi_replace(":##", "://", $line);
 
       # Links between items
-      $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\">[bugs&nbsp;#\\2]</a>", $line);
-      $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\">[support&nbsp;#\\2]</a>", $line);
-      $line = eregi_replace("task[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."task/?func=detailitem&amp;item_id=\\1\">[task&nbsp;#\\1]</a>", $line);
-      $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\">[patch&nbsp;#\\1]</a>", $line);
+      $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\">bug&nbsp;#\\2</a>", $line);
+      $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\">support&nbsp;#\\2</a>", $line);
+      $line = eregi_replace("task[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."task/?func=detailitem&amp;item_id=\\1\">task&nbsp;#\\1</a>", $line);
+      $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\">patch&nbsp;#\\1</a>", $line);
 
 
 
@@ -427,14 +427,7 @@ function utils_double_diff_array($arr1, $arr2)
 
 function utils_registration_history ($unix_group_name)
 {
-  if ($unix_group_name != "")
-    {
-      $register_discard = `grep $unix_group_name /var/log/sv_register_discard.log`;
-      if ($register_discard != "")
-	{
-	  return '<b>Registration history:</b><br>'.nl2br($register_discard);
-	}
-    }
+  # Meaningless with chrooted system; all www system should be chrooted.
 }
 
 function show_priority_colors_key()
