@@ -1,32 +1,28 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: index.php,v 1.71 2004/03/06 16:53:35 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: index.php,v 1.73 2004/03/26 17:51:49 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#
+#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 require "../../include/pre.php";
 
@@ -37,7 +33,7 @@ if ($group_id && user_ismember($group_id,'A'))
 
   $grp=project_get_object($group_id);
 
-  // FIXME: GNU specific
+  # FIXME: GNU specific
   if ($project->getTypeName() == 'GNU' || $project->getTypeName() == 'www.gnu.org' && $GLOBALS[sys_default_domain] == "savannah.gnu.org")
     { $isgnu = true; }
   else
@@ -50,13 +46,13 @@ if ($group_id && user_ismember($group_id,'A'))
 	Update the DB to reflect the changes
       ***********************************************************/
 
-      // Add a new list
+      # Add a new list
       if ($add_list)
 	{
-	  // Generates a password
+	  # Generates a password
 	  $list_password = substr(md5($GLOBALS['session_hash'] . time() . rand(0,40000)),0,16);
 
-	  // Defines the list name
+	  # Defines the list name
 	  if ($type != "0" && $type!="1" && $type!="2" && $type!="3" && $isgnu==true)
 	    { exit_error('Error','Radio button not checked'); }
 
@@ -89,12 +85,12 @@ if ($group_id && user_ismember($group_id,'A'))
 	    }
 	  else
 	    {
-	      // FIXME name convention
+	      # FIXME name convention
 	      $new_list_name=strtolower(group_getunixname($group_id).'-'.$list_name);
 	    }
 
-	  // Check on the list_name: must not be equal to a user account,
-	  // otherwise it can mess up the mail develivery for the list/user
+	  # Check on the list_name: must not be equal to a user account,
+	  # otherwise it can mess up the mail develivery for the list/user
 	  if (db_numrows(db_query("SELECT user_id FROM user WHERE "
 				  . "user_name LIKE '".addslashes($list_name)."'")) > 0)
 	    {
@@ -102,11 +98,11 @@ if ($group_id && user_ismember($group_id,'A'))
 	    }
 
 
-	  // If no host is available, we do not have to interfere with
-	  // another host for list create, we do not nothing
-	  // Currently, it only handles GNU mailman.
-	  // If this part needs to be changed, please write to
-	  // savannah-dev@gnu.org first.
+	  # If no host is available, we do not have to interfere with
+	  # another host for list create, we do not nothing
+	  # Currently, it only handles GNU mailman.
+	  # If this part needs to be changed, please write to
+	  # savannah-dev@gnu.org first.
 	  if ($project->getTypeMailingListHost())
 	    {
 	      $site = "http://".$project->getTypeMailingListHost().
@@ -138,12 +134,12 @@ if ($group_id && user_ismember($group_id,'A'))
 	      $parse[0] = substr($parse[0],0,1);
 	      if ($parse[0] != "0")
 		{
-		  // The validation ignores the domain
+		  # The validation ignores the domain
 		  "Sorry, $new_list_name already exists";
 		}
 	      elseif (validate_email($project->getTypeMailingListAddress($new_list_name)))
 		{
-		  // FIXME name convention
+		  # FIXME name convention
 		  $new_list_name=strtolower(group_getunixname($group_id).'-'.$list_name);
 
 		}
@@ -182,7 +178,7 @@ if ($group_id && user_ismember($group_id,'A'))
 			  " List Added ";
 			}
 
-		      // Send confirmation mail (only if we now the host)
+		      # Send confirmation mail (only if we now the host)
 
 		      $res_email = db_query("SELECT email FROM user WHERE user_id='".user_getid()."'");
 
@@ -194,7 +190,7 @@ if ($group_id && user_ismember($group_id,'A'))
 
 		      $mlhost=$project->getTypeMailingListHost();
 
-		      // mail password to admin
+		      # mail password to admin
 		      $message = "A mailing list will be created on fencepost in less than 2 hours \n"
 			 . "and you are the list administrator.\n\n"
 			 . "This list is: $new_list_name" .$mldomain ."\n\n"
@@ -222,7 +218,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	    }
 	  else
 	    {
-	      // No mail host defined, just update the database
+	      # No mail host defined, just update the database
 	      $result=db_query("SELECT * FROM mail_group_list WHERE lower(list_name)='$new_list_name'");
 
 
@@ -257,7 +253,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	    }
 
 	} else if ($change_status) {
-	  // list name is fixed
+	  # list name is fixed
 	  $sql="UPDATE mail_group_list SET is_public='$is_public', ".
 	     "description='". htmlspecialchars($description) ."' ".
 	     "WHERE group_list_id='$group_list_id' AND group_id='$group_id'";
@@ -279,7 +275,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	Show forms to make changes
   ***********************************************************/
 
-  // Show the form for adding lists
+  # Show the form for adding lists
   if ($add_list)
     {
 
@@ -287,9 +283,14 @@ if ($group_id && user_ismember($group_id,'A'))
 
       utils_get_content("mail/about_list_creation");
 
-      $result=db_query("SELECT list_name FROM mail_group_list WHERE group_id='$group_id'");
+      $result = db_query("SELECT list_name,group_list_id FROM mail_group_list WHERE group_id='$group_id'");
+      $rows=db_numrows($result);
 
-      ShowResultSet($result,'Mailing Lists already in use');
+      print '<h3>Mailing Lists already in use</h3>';
+      for ($k=0; $k < $rows; $k++)
+	{
+	  echo '<div class="'.utils_get_alt_row_color($k).'">'.db_result($result, $k, "list_name").'</div>';
+	}
 
       print '
 			<p>
@@ -297,7 +298,7 @@ if ($group_id && user_ismember($group_id,'A'))
 			<input type="hidden" name="post_changes" value="y">
 			<input type="hidden" name="add_list" value="y">
 			<input type="hidden" name="group_id" value="'.$group_id.'">
-			<b>Mailing List Name:</b> <br>';
+			<h3>Mailing List Name:</h3> ';
 
       if ($isgnu == true)
 	{ print '<INPUT TYPE="radio" NAME="type" VALUE="0" CHECKED>'; }
@@ -316,7 +317,7 @@ if ($group_id && user_ismember($group_id,'A'))
 
       print '
 			<P></P>
-			<B>Is Public</B> (visible for non-developers)<B>?</B><BR>
+			<h3>Is Public ?</h3> (visible for non-developers)<BR>
 			<INPUT TYPE="RADIO" NAME="is_public" VALUE="1" CHECKED> Yes<BR>
 			<INPUT TYPE="RADIO" NAME="is_public" VALUE="0"> No<P></P>
 			<B>Description:</B><BR>
@@ -330,7 +331,7 @@ if ($group_id && user_ismember($group_id,'A'))
     }
   else if ($change_status)
     {
-      // Show the form to modify lists status
+      # Show the form to modify lists status
 
     site_project_header(array('title'=>_("Update Mailing List"),'group'=>$group_id,'toptab'=>'amail'));
 
@@ -404,9 +405,9 @@ if ($group_id && user_ismember($group_id,'A'))
   else if ($migrate)
     {
 
-      // Note: I did not checked that part of the code, that should remain
-      // unchanged. Hope it will still work.
-      // yeupou@gnu.org 2003-09-24
+      # Note: I did not checked that part of the code, that should remain
+      # unchanged. Hope it will still work.
+      # yeupou@gnu.org 2003-09-24
       mail_header(array('title'=>'Migrate Mailing Lists'));
 
       if ($isgnu == false)
@@ -422,7 +423,7 @@ if ($group_id && user_ismember($group_id,'A'))
 
 	  $site = $project->getTypeMailingListListinfoUrl();
 	  $site .= '../sfverify?list=';
-	  //$site = "http://mail.gnu.org/mailman/sfverify?list=";
+	  #$site = "http://mail.gnu.org/mailman/sfverify?list=";
 	  $site .= urlencode($list);
 	  $site .= "&password=";
 	  $site .= urlencode($password);
@@ -458,7 +459,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	  } else {
 	    $admin_email = addslashes($parse[1]);
 	    $is_public = addslashes($parse[2]);
-	    $desc = $parse[3]; // join(array_slice($parse,3)," ");
+	    $desc = $parse[3]; # join(array_slice($parse,3)," ");
 	    $sql =  "SELECT list_name ".
 	       "FROM mail_group_list ".
 	       "WHERE list_name = '".addslashes($list)."'";
