@@ -1,55 +1,47 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: approve.php,v 1.5 2004/03/04 18:55:45 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation,
-//                          Mathieu Roy <yeupou@gnu.org>,
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: approve.php,v 1.6 2004/03/13 18:22:06 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#                          Mathieu Roy <yeupou--at--gnu.org>
+#
+#  Copyright 2004      (c) ...
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 require '../include/pre.php';
 
-/*
-
-This page can be used to manage the whole news system for a server
-  or news for a project.
-  That why, when required, we test if group_id = sys_group_id.
-
-*/
+# This page can be used to manage the whole news system for a server
+# or news for a project.
+# That's why, when required, we test if group_id = sys_group_id.
 
 if ($group_id && member_check(0, $group_id,'N3'))
 {
 
-  // Modifications are made to the database
+  # Modifications are made to the database
   if ($post_changes && $approve)
     {
 
       if ($group_id != $GLOBALS['sys_group_id'] &&
 	  $status != 0 && $status != 4)
 	{
-	  // Make sure that an item accepted for front page is not modified
+	  # Make sure that an item accepted for front page is not modified
 	  $status=0;
 	}
 
@@ -91,12 +83,12 @@ if ($group_id && member_check(0, $group_id,'N3'))
 
     }
 
-  // Begin HTML
+  # Begin HTML
   site_project_header(array('title'=>_("Manage"),
 			    'group'=>$group_id,
 			    'toptab'=>'news'));
 
-  // Form to make modifications to an existing item, to submit one
+  # Form to make modifications to an existing item, to submit one
   if ($approve)
     {
 
@@ -157,14 +149,14 @@ if ($group_id && member_check(0, $group_id,'N3'))
     }
   else
     {
-      // No item selected
+      # No item selected
 
       $old_date=(time()-(86400*7));
 
-      // Firstly, we show item that require approval
-      //   - if site news: it has to be already approved projects (0)
-      //     or project submitted on the system site project
-      //   - if project news: it has to be proposed news (5)
+      # Firstly, we show item that require approval
+      #   - if site news: it has to be already approved projects (0)
+      #     or project submitted on the system site project
+      #   - if project news: it has to be proposed news (5)
       if (user_ismember($GLOBALS['sys_group_id'],'A') && $group_id == $GLOBALS['sys_group_id'])
 	{
 	  $sql="SELECT * FROM news_bytes WHERE is_approved=0 AND date > '$old_date' OR group_id='$sys_group_id'";
@@ -204,7 +196,7 @@ if ($group_id && member_check(0, $group_id,'N3'))
 	  print '</ul>';
 	}
 
-      // Secondly, we show deleted items for this week
+      # Secondly, we show deleted items for this week
 
       if (user_ismember($GLOBALS['sys_group_id'],'A') && $group_id == $GLOBALS['sys_group_id'])
 	{
@@ -244,7 +236,7 @@ if ($group_id && member_check(0, $group_id,'N3'))
 	  print '</ul>';
 	}
 
-      // Finally, we show approved items for this week
+      # Finally, we show approved items for this week
       if (user_ismember($GLOBALS['sys_group_id'],'A') && $group_id == $GLOBALS['sys_group_id'])
 	{
 	  $sql="SELECT * FROM news_bytes WHERE is_approved=1 AND date > '$old_date'";
