@@ -1,36 +1,33 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: index.php,v 1.40 2004/03/06 14:07:58 toddy Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: index.php,v 1.42 2004/03/13 18:22:06 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#                          Mathieu Roy <yeupou--at--gnu.org>
+# 
+#  Copyright 2004      (c) ...
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 require '../include/pre.php';
 
-// No words? Ask for them
+# No words? Ask for them
 if (!$words)
 {
   search_send_header();
@@ -39,7 +36,7 @@ if (!$words)
   exit;
 }
 
-// Do the search
+# Do the search
 if ($type_of_search == "google")
 {
   Header("Location: http://www.google.com/search?q=site:".$GLOBALS['sys_default_domain']."+$words");
@@ -50,7 +47,7 @@ else
   $result = search_run($words, $type_of_search);
 }
 
-// Print out the results
+# Print out the results
 
 if ($type_of_search == "soft")
 {
@@ -58,12 +55,14 @@ if ($type_of_search == "soft")
 
   if (!$result || $rows < 1)
     {
-      // No result? Stop here.
+      # No result? Stop here.
       search_failed();
     }
-  elseif ($rows == 1)
+  elseif (($rows == 1) && ($GLOBALS['offset'] == 0))
     {
-      // Only one result ? Redirect!
+      # Only one result? Redirect, but only if this is the first
+      # page to be displayed. Otherwise, if the last page contains
+      # just one row, the user will be redirected.
       $res_type = db_query("SELECT base_host FROM group_type WHERE type_id=".db_result($result, 0, 'type'));
       $project = db_result($result, 0, 'unix_group_name');
       if (db_result($res_type, 0, 'base_host'))
@@ -75,7 +74,7 @@ if ($type_of_search == "soft")
     }
   else
     {
-      // More results? Print them in the respect of max_rows setting.
+      # More results? Print them in the respect of max_rows setting.
       if ($rows_returned > $GLOBALS['max_rows'])
 	{ $rows = $GLOBALS['max_rows']; }
       search_send_header();
@@ -115,7 +114,7 @@ else if ($type_of_search == "people")
     {
       search_failed();
     }
-  elseif ( $rows == 1 )
+  elseif (($rows == 1) && ($GLOBALS['offset'] == 0))
     {
       $user = db_result($result, 0, 'user_name');
       Header("Location: ".$GLOBALS['sys_home']."users/$user");
@@ -166,11 +165,11 @@ else if ($type_of_search == "people")
 
   if (!$result || $rows < 1)
     {
-      //		$no_rows = 1;
+      #		$no_rows = 1;
       search_failed();
 
     }
-  else if ( $rows == 1 )
+  elseif (($rows == 1) && ($GLOBALS['offset'] == 0))
     {
       $msg = db_result($result, 0, 'msg_id');
       Header("Location: ".$GLOBALS['sys_home']."forum/message.php?msg_id=$msg");
@@ -217,7 +216,7 @@ else if ($type_of_search == 'bugs' ||
     {
       search_failed();
     }
-  else if ($rows == 1)
+  elseif (($rows == 1) && ($GLOBALS['offset'] == 0))
     {
       $bug = db_result($result, 0, 'bug_id');
       Header("Location: ".$GLOBALS['sys_home'].$type_of_search."/?func=detailitem&item_id=$bug");
